{-# LANGUAGE MagicHash #-}
{-# LANGUAGE ScopedTypeVariables #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}

module Curry_RedBlackTree
  ( C_RedBlackTree (..)
  , C_Color (..)
  , C_Tree (..)
  , d_C_empty
  , nd_C_empty
  , d_C_isEmpty
  , nd_C_isEmpty
  , d_C_newTreeLike
  , nd_C_newTreeLike
  , d_C_lookup
  , nd_C_lookup
  , d_C_update
  , nd_C_update
  , d_C_delete
  , nd_C_delete
  , d_C_tree2list
  , nd_C_tree2list
  , d_C_sortBy
  , nd_C_sortBy
  , d_C_setInsertEquivalence
  , nd_C_setInsertEquivalence )
  where

import Basics
import qualified Curry_Prelude


data C_RedBlackTree t0
  = C_RedBlackTree (t0 -> Cover -> ConstStore -> t0 -> Cover -> ConstStore
    -> Curry_Prelude.C_Bool) (t0 -> Cover -> ConstStore -> t0 -> Cover
    -> ConstStore -> Curry_Prelude.C_Bool) (t0 -> Cover -> ConstStore -> t0
    -> Cover -> ConstStore -> Curry_Prelude.C_Bool) (C_Tree t0)
  | HO_C_RedBlackTree (Func t0 (Func t0 Curry_Prelude.C_Bool)) (Func t0 (Func t0
    Curry_Prelude.C_Bool)) (Func t0 (Func t0 Curry_Prelude.C_Bool)) (C_Tree t0)
  | Choice_C_RedBlackTree Cover ID (C_RedBlackTree t0) (C_RedBlackTree t0)
  | Choices_C_RedBlackTree Cover ID [C_RedBlackTree t0]
  | Fail_C_RedBlackTree Cover FailInfo
  | Guard_C_RedBlackTree Cover Constraints (C_RedBlackTree t0)

instance (Show t0) => Show (C_RedBlackTree t0) where
  showsPrec d (Choice_C_RedBlackTree cd i x y) = showsChoice d cd i x y
  showsPrec d (Choices_C_RedBlackTree cd i xs) = showsChoices d cd i xs
  showsPrec d (Guard_C_RedBlackTree cd c e) = showsGuard d cd c e
  showsPrec _ (Fail_C_RedBlackTree cd info) = showChar '!'
  showsPrec _ (C_RedBlackTree x1 x2 x3 x4) = showString "(RedBlackTree" .
    (showChar ' ' . (shows x1 . (showChar ' ' . (shows x2 . (showChar ' ' .
    (shows x3 . (showChar ' ' . (shows x4 . showChar ')'))))))))
  showsPrec _ (HO_C_RedBlackTree x1 x2 x3 x4) = showString "(RedBlackTree" .
    (showChar ' ' . (shows x1 . (showChar ' ' . (shows x2 . (showChar ' ' .
    (shows x3 . (showChar ' ' . (shows x4 . showChar ')'))))))))

instance (Read t0) => Read (C_RedBlackTree t0) where
  readsPrec d s = readParen ((>) d 10) (\r -> [(C_RedBlackTree x1 x2 x3 x4
    , r4) | (_, r0) <- readQualified "RedBlackTree" "RedBlackTree" r, (x1, r1)
    <- readsPrec 11 r0, (x2, r2) <- readsPrec 11 r1, (x3, r3) <- readsPrec 11
    r2, (x4, r4) <- readsPrec 11 r3]) s

instance NonDet (C_RedBlackTree t0) where
  choiceCons = Choice_C_RedBlackTree
  choicesCons = Choices_C_RedBlackTree
  failCons = Fail_C_RedBlackTree
  guardCons = Guard_C_RedBlackTree
  try (Choice_C_RedBlackTree cd i x y) = tryChoice cd i x y
  try (Choices_C_RedBlackTree cd i xs) = tryChoices cd i xs
  try (Fail_C_RedBlackTree cd info) = Fail cd info
  try (Guard_C_RedBlackTree cd c e) = Guard cd c e
  try x = Val x
  match f _ _ _ _ _ (Choice_C_RedBlackTree cd i x y) = f cd i x y
  match _ f _ _ _ _ (Choices_C_RedBlackTree cd i@(NarrowedID _ _) xs) = f cd i
    xs
  match _ _ f _ _ _ (Choices_C_RedBlackTree cd i@(FreeID _ _) xs) = f cd i xs
  match _ _ _ _ _ _ (Choices_C_RedBlackTree cd i _) = error
    ("RedBlackTree.RedBlackTree.match: Choices with ChoiceID " ++ show i)
  match _ _ _ f _ _ (Fail_C_RedBlackTree cd info) = f cd info
  match _ _ _ _ f _ (Guard_C_RedBlackTree cd c e) = f cd c e
  match _ _ _ _ _ f x = f x

instance (Generable t0) => Generable (C_RedBlackTree t0) where
  generate s c = Choices_C_RedBlackTree c (freeID [4] s) [HO_C_RedBlackTree
    (generate (leftSupply (leftSupply s)) c) (generate (rightSupply (leftSupply
    s)) c) (generate (leftSupply (rightSupply s)) c) (generate (rightSupply
    (rightSupply s)) c)]

instance (NormalForm t0) => NormalForm (C_RedBlackTree t0) where
  ($!!) cont (C_RedBlackTree x1 x2 x3 x4) d cs = ($!!) (\y1 d cs -> ($!!)
    (\y2 d cs -> ($!!) (\y3 d cs -> ($!!) (\y4 d cs -> cont (C_RedBlackTree y1
    y2 y3 y4) d cs) x4 d cs) x3 d cs) x2 d cs) x1 d cs
  ($!!) cont (HO_C_RedBlackTree x1 x2 x3 x4) d cs = ($!!) (\y1 d cs -> ($!!)
    (\y2 d cs -> ($!!) (\y3 d cs -> ($!!) (\y4 d cs -> cont (HO_C_RedBlackTree
    y1 y2 y3 y4) d cs) x4 d cs) x3 d cs) x2 d cs) x1 d cs
  ($!!) cont (Choice_C_RedBlackTree cd i x y) d cs = nfChoice cont cd i x y cd
    cs
  ($!!) cont (Choices_C_RedBlackTree cd i xs) d cs = nfChoices cont cd i xs d cs
  ($!!) cont (Guard_C_RedBlackTree cd c e) d cs = guardCons cd c (($!!) cont e d
    (addCs c cs))
  ($!!) _ (Fail_C_RedBlackTree cd info) _ _ = failCons cd info
  ($##) cont (C_RedBlackTree x1 x2 x3 x4) d cs = ($##) (\y1 d cs -> ($##)
    (\y2 d cs -> ($##) (\y3 d cs -> ($##) (\y4 d cs -> cont (C_RedBlackTree y1
    y2 y3 y4) d cs) x4 d cs) x3 d cs) x2 d cs) x1 d cs
  ($##) cont (HO_C_RedBlackTree x1 x2 x3 x4) d cs = ($##) (\y1 d cs -> ($##)
    (\y2 d cs -> ($##) (\y3 d cs -> ($##) (\y4 d cs -> cont (HO_C_RedBlackTree
    y1 y2 y3 y4) d cs) x4 d cs) x3 d cs) x2 d cs) x1 d cs
  ($##) cont (Choice_C_RedBlackTree cd i x y) d cs = gnfChoice cont cd i x y cd
    cs
  ($##) cont (Choices_C_RedBlackTree cd i xs) d cs = gnfChoices cont cd i xs d
    cs
  ($##) cont (Guard_C_RedBlackTree cd c e) d cs = guardCons cd c (($##) cont e d
    (addCs c cs))
  ($##) _ (Fail_C_RedBlackTree cd info) _ _ = failCons cd info
  showCons (C_RedBlackTree _ _ _ _) = "RedBlackTree.RedBlackTree _ _ _ _"
  showCons (HO_C_RedBlackTree _ _ _ _) = "RedBlackTree.RedBlackTree _ _ _ _"
  showCons x = error ("RedBlackTree.RedBlackTree.showCons: no constructor: " ++
    show x)
  searchNF search cont (C_RedBlackTree x1 x2 x3 x4) = search (\y1 -> search
    (\y2 -> search (\y3 -> search (\y4 -> cont (C_RedBlackTree y1 y2 y3 y4)) x4)
    x3) x2) x1
  searchNF search cont (HO_C_RedBlackTree x1 x2 x3 x4) = search (\y1 -> search
    (\y2 -> search (\y3 -> search (\y4 -> cont (HO_C_RedBlackTree y1 y2 y3 y4))
    x4) x3) x2) x1
  searchNF _ _ x = error
    ("RedBlackTree.RedBlackTree.searchNF: no constructor: " ++ show x)

instance (Unifiable t0) => Unifiable (C_RedBlackTree t0) where
  (=.=) (C_RedBlackTree x1 x2 x3 x4) (C_RedBlackTree y1 y2 y3 y4) d cs = (&)
    ((=:=) x1 y1 d cs) ((&) ((=:=) x2 y2 d cs) ((&) ((=:=) x3 y3 d cs) ((=:=) x4
    y4 d cs) d cs) d cs) d cs
  (=.=) (HO_C_RedBlackTree x1 x2 x3 x4) (HO_C_RedBlackTree y1 y2 y3 y4) d cs =
    (&) ((=:=) x1 y1 d cs) ((&) ((=:=) x2 y2 d cs) ((&) ((=:=) x3 y3 d cs)
    ((=:=) x4 y4 d cs) d cs) d cs) d cs
  (=.=) a b cd _ = Fail_C_Bool cd (unificationFail (showCons a) (showCons b))
  (=.<=) (C_RedBlackTree x1 x2 x3 x4) (C_RedBlackTree y1 y2 y3 y4) d cs = (&)
    ((=:<=) x1 y1 d cs) ((&) ((=:<=) x2 y2 d cs) ((&) ((=:<=) x3 y3 d cs)
    ((=:<=) x4 y4 d cs) d cs) d cs) d cs
  (=.<=) (HO_C_RedBlackTree x1 x2 x3 x4) (HO_C_RedBlackTree y1 y2 y3 y4) d cs =
    (&) ((=:<=) x1 y1 d cs) ((&) ((=:<=) x2 y2 d cs) ((&) ((=:<=) x3 y3 d cs)
    ((=:<=) x4 y4 d cs) d cs) d cs) d cs
  (=.<=) a b cd _ = Fail_C_Bool cd (unificationFail (showCons a) (showCons b))
  bind cd i (C_RedBlackTree x3 x4 x5 x6) = (i :=: ChooseN 0 4) : concat [bind cd
    (leftID (leftID i)) x3, bind cd (rightID (leftID i)) x4, bind cd (leftID
    (rightID i)) x5, bind cd (rightID (rightID i)) x6]
  bind cd i (HO_C_RedBlackTree x3 x4 x5 x6) = (i :=: ChooseN 0 4) : concat [bind
    cd (leftID (leftID i)) x3, bind cd (rightID (leftID i)) x4, bind cd (leftID
    (rightID i)) x5, bind cd (rightID (rightID i)) x6]
  bind d i (Choice_C_RedBlackTree cd j x y) = [ConstraintChoice cd j (bind d i
    x) (bind d i y)]
  bind d i (Choices_C_RedBlackTree cd j@(FreeID _ _) xs) = bindOrNarrow d i cd j
    xs
  bind d i (Choices_C_RedBlackTree cd j@(NarrowedID _ _) xs) =
    [ConstraintChoices cd j (map (bind d i) xs)]
  bind _ _ (Choices_C_RedBlackTree cd i _) = error
    ("RedBlackTree.RedBlackTree.bind: Choices with ChoiceID: " ++ show i)
  bind _ _ (Fail_C_RedBlackTree cd info) = [Unsolvable info]
  bind d i (Guard_C_RedBlackTree cd c e) = getConstrList c ++ bind d i e
  lazyBind cd i (C_RedBlackTree x3 x4 x5 x6) = (i :=: ChooseN 0 4) : [leftID
    (leftID i) :=: LazyBind (lazyBind cd (leftID (leftID i)) x3), rightID
    (leftID i) :=: LazyBind (lazyBind cd (rightID (leftID i)) x4), leftID
    (rightID i) :=: LazyBind (lazyBind cd (leftID (rightID i)) x5), rightID
    (rightID i) :=: LazyBind (lazyBind cd (rightID (rightID i)) x6)]
  lazyBind cd i (HO_C_RedBlackTree x3 x4 x5 x6) = (i :=: ChooseN 0 4) : [leftID
    (leftID i) :=: LazyBind (lazyBind cd (leftID (leftID i)) x3), rightID
    (leftID i) :=: LazyBind (lazyBind cd (rightID (leftID i)) x4), leftID
    (rightID i) :=: LazyBind (lazyBind cd (leftID (rightID i)) x5), rightID
    (rightID i) :=: LazyBind (lazyBind cd (rightID (rightID i)) x6)]
  lazyBind d i (Choice_C_RedBlackTree cd j x y) = [ConstraintChoice cd j
    (lazyBind d i x) (lazyBind d i y)]
  lazyBind d i (Choices_C_RedBlackTree cd j@(FreeID _ _) xs) = lazyBindOrNarrow
    d i cd j xs
  lazyBind d i (Choices_C_RedBlackTree cd j@(NarrowedID _ _) xs) =
    [ConstraintChoices cd j (map (lazyBind d i) xs)]
  lazyBind _ _ (Choices_C_RedBlackTree cd i _) = error
    ("RedBlackTree.RedBlackTree.lazyBind: Choices with ChoiceID: " ++ show i)
  lazyBind _ _ (Fail_C_RedBlackTree cd info) = [Unsolvable info]
  lazyBind d i (Guard_C_RedBlackTree cd c e) = getConstrList c ++ [i :=:
    LazyBind (lazyBind d i e)]

instance (Curry t0) => Curry (C_RedBlackTree t0) where
  (=?=) (Choice_C_RedBlackTree cd i x y) z d cs = narrow cd i ((=?=) x z d cs)
    ((=?=) y z d cs)
  (=?=) (Choices_C_RedBlackTree cd i xs) y d cs = narrows cs cd i (\x -> (=?=) x
    y d cs) xs
  (=?=) (Guard_C_RedBlackTree cd c e) y d cs = guardCons cd c ((=?=) e y d
    (addCs c cs))
  (=?=) (Fail_C_RedBlackTree cd info) _ _ _ = failCons cd info
  (=?=) z (Choice_C_RedBlackTree cd i x y) d cs = narrow cd i ((=?=) z x d cs)
    ((=?=) z y d cs)
  (=?=) y (Choices_C_RedBlackTree cd i xs) d cs = narrows cs cd i (\x -> (=?=) y
    x d cs) xs
  (=?=) y (Guard_C_RedBlackTree cd c e) d cs = guardCons cd c ((=?=) y e d
    (addCs c cs))
  (=?=) _ (Fail_C_RedBlackTree cd info) _ _ = failCons cd info
  (=?=) (C_RedBlackTree x1 x2 x3 x4) (C_RedBlackTree y1 y2 y3 y4) d cs =
    Curry_Prelude.d_OP_amp_amp ((=?=) x1 y1 d cs) (Curry_Prelude.d_OP_amp_amp
    ((=?=) x2 y2 d cs) (Curry_Prelude.d_OP_amp_amp ((=?=) x3 y3 d cs) ((=?=) x4
    y4 d cs) d cs) d cs) d cs
  (=?=) (HO_C_RedBlackTree x1 x2 x3 x4) (HO_C_RedBlackTree y1 y2 y3 y4) d cs =
    Curry_Prelude.d_OP_amp_amp ((=?=) x1 y1 d cs) (Curry_Prelude.d_OP_amp_amp
    ((=?=) x2 y2 d cs) (Curry_Prelude.d_OP_amp_amp ((=?=) x3 y3 d cs) ((=?=) x4
    y4 d cs) d cs) d cs) d cs
  (<?=) (Choice_C_RedBlackTree cd i x y) z d cs = narrow cd i ((<?=) x z d cs)
    ((<?=) y z d cs)
  (<?=) (Choices_C_RedBlackTree cd i xs) y d cs = narrows cs cd i (\x -> (<?=) x
    y d cs) xs
  (<?=) (Guard_C_RedBlackTree cd c e) y d cs = guardCons cd c ((<?=) e y d
    (addCs c cs))
  (<?=) (Fail_C_RedBlackTree cd info) _ _ _ = failCons cd info
  (<?=) z (Choice_C_RedBlackTree cd i x y) d cs = narrow cd i ((<?=) z x d cs)
    ((<?=) z y d cs)
  (<?=) y (Choices_C_RedBlackTree cd i xs) d cs = narrows cs cd i (\x -> (<?=) y
    x d cs) xs
  (<?=) y (Guard_C_RedBlackTree cd c e) d cs = guardCons cd c ((<?=) y e d
    (addCs c cs))
  (<?=) _ (Fail_C_RedBlackTree cd info) _ _ = failCons cd info
  (<?=) (C_RedBlackTree x1 x2 x3 x4) (C_RedBlackTree y1 y2 y3 y4) d cs =
    Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x1 y1 d cs)
    (Curry_Prelude.d_OP_amp_amp ((=?=) x1 y1 d cs) (Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_OP_lt x2 y2 d cs) (Curry_Prelude.d_OP_amp_amp ((=?=) x2 y2
    d cs) (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x3 y3 d cs)
    (Curry_Prelude.d_OP_amp_amp ((=?=) x3 y3 d cs) ((<?=) x4 y4 d cs) d cs) d
    cs) d cs) d cs) d cs) d cs
  (<?=) (HO_C_RedBlackTree x1 x2 x3 x4) (HO_C_RedBlackTree y1 y2 y3 y4) d cs =
    Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x1 y1 d cs)
    (Curry_Prelude.d_OP_amp_amp ((=?=) x1 y1 d cs) (Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_OP_lt x2 y2 d cs) (Curry_Prelude.d_OP_amp_amp ((=?=) x2 y2
    d cs) (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x3 y3 d cs)
    (Curry_Prelude.d_OP_amp_amp ((=?=) x3 y3 d cs) ((<?=) x4 y4 d cs) d cs) d
    cs) d cs) d cs) d cs) d cs

data C_Color
  = C_Red
  | C_Black
  | C_DoublyBlack
  | Choice_C_Color Cover ID C_Color C_Color
  | Choices_C_Color Cover ID [C_Color]
  | Fail_C_Color Cover FailInfo
  | Guard_C_Color Cover Constraints C_Color

instance Show C_Color where
  showsPrec d (Choice_C_Color cd i x y) = showsChoice d cd i x y
  showsPrec d (Choices_C_Color cd i xs) = showsChoices d cd i xs
  showsPrec d (Guard_C_Color cd c e) = showsGuard d cd c e
  showsPrec _ (Fail_C_Color cd info) = showChar '!'
  showsPrec _ C_Red = showString "Red"
  showsPrec _ C_Black = showString "Black"
  showsPrec _ C_DoublyBlack = showString "DoublyBlack"

instance Read C_Color where
  readsPrec _ s = readParen False (\r -> [(C_Red, r0) | (_, r0) <- readQualified
    "RedBlackTree" "Red" r]) s ++ (readParen False (\r -> [(C_Black, r0) | (_
    , r0) <- readQualified "RedBlackTree" "Black" r]) s ++ readParen False
    (\r -> [(C_DoublyBlack, r0) | (_, r0) <- readQualified "RedBlackTree"
    "DoublyBlack" r]) s)

instance NonDet C_Color where
  choiceCons = Choice_C_Color
  choicesCons = Choices_C_Color
  failCons = Fail_C_Color
  guardCons = Guard_C_Color
  try (Choice_C_Color cd i x y) = tryChoice cd i x y
  try (Choices_C_Color cd i xs) = tryChoices cd i xs
  try (Fail_C_Color cd info) = Fail cd info
  try (Guard_C_Color cd c e) = Guard cd c e
  try x = Val x
  match f _ _ _ _ _ (Choice_C_Color cd i x y) = f cd i x y
  match _ f _ _ _ _ (Choices_C_Color cd i@(NarrowedID _ _) xs) = f cd i xs
  match _ _ f _ _ _ (Choices_C_Color cd i@(FreeID _ _) xs) = f cd i xs
  match _ _ _ _ _ _ (Choices_C_Color cd i _) = error
    ("RedBlackTree.Color.match: Choices with ChoiceID " ++ show i)
  match _ _ _ f _ _ (Fail_C_Color cd info) = f cd info
  match _ _ _ _ f _ (Guard_C_Color cd c e) = f cd c e
  match _ _ _ _ _ f x = f x

instance Generable C_Color where
  generate s c = Choices_C_Color c (freeID [0, 0, 0] s) [C_Red, C_Black
    , C_DoublyBlack]

instance NormalForm C_Color where
  ($!!) cont C_Red d cs = cont C_Red d cs
  ($!!) cont C_Black d cs = cont C_Black d cs
  ($!!) cont C_DoublyBlack d cs = cont C_DoublyBlack d cs
  ($!!) cont (Choice_C_Color cd i x y) d cs = nfChoice cont cd i x y cd cs
  ($!!) cont (Choices_C_Color cd i xs) d cs = nfChoices cont cd i xs d cs
  ($!!) cont (Guard_C_Color cd c e) d cs = guardCons cd c (($!!) cont e d (addCs
    c cs))
  ($!!) _ (Fail_C_Color cd info) _ _ = failCons cd info
  ($##) cont C_Red d cs = cont C_Red d cs
  ($##) cont C_Black d cs = cont C_Black d cs
  ($##) cont C_DoublyBlack d cs = cont C_DoublyBlack d cs
  ($##) cont (Choice_C_Color cd i x y) d cs = gnfChoice cont cd i x y cd cs
  ($##) cont (Choices_C_Color cd i xs) d cs = gnfChoices cont cd i xs d cs
  ($##) cont (Guard_C_Color cd c e) d cs = guardCons cd c (($##) cont e d (addCs
    c cs))
  ($##) _ (Fail_C_Color cd info) _ _ = failCons cd info
  showCons C_Red = "RedBlackTree.Red"
  showCons C_Black = "RedBlackTree.Black"
  showCons C_DoublyBlack = "RedBlackTree.DoublyBlack"
  showCons x = error ("RedBlackTree.Color.showCons: no constructor: " ++ show x)
  searchNF _ cont C_Red = cont C_Red
  searchNF _ cont C_Black = cont C_Black
  searchNF _ cont C_DoublyBlack = cont C_DoublyBlack
  searchNF _ _ x = error ("RedBlackTree.Color.searchNF: no constructor: " ++
    show x)

instance Unifiable C_Color where
  (=.=) C_Red C_Red d cs = C_True
  (=.=) C_Black C_Black d cs = C_True
  (=.=) C_DoublyBlack C_DoublyBlack d cs = C_True
  (=.=) a b cd _ = Fail_C_Bool cd (unificationFail (showCons a) (showCons b))
  (=.<=) C_Red C_Red d cs = C_True
  (=.<=) C_Black C_Black d cs = C_True
  (=.<=) C_DoublyBlack C_DoublyBlack d cs = C_True
  (=.<=) a b cd _ = Fail_C_Bool cd (unificationFail (showCons a) (showCons b))
  bind cd i C_Red = (i :=: ChooseN 0 0) : concat []
  bind cd i C_Black = (i :=: ChooseN 1 0) : concat []
  bind cd i C_DoublyBlack = (i :=: ChooseN 2 0) : concat []
  bind d i (Choice_C_Color cd j x y) = [ConstraintChoice cd j (bind d i x) (bind
    d i y)]
  bind d i (Choices_C_Color cd j@(FreeID _ _) xs) = bindOrNarrow d i cd j xs
  bind d i (Choices_C_Color cd j@(NarrowedID _ _) xs) = [ConstraintChoices cd j
    (map (bind d i) xs)]
  bind _ _ (Choices_C_Color cd i _) = error
    ("RedBlackTree.Color.bind: Choices with ChoiceID: " ++ show i)
  bind _ _ (Fail_C_Color cd info) = [Unsolvable info]
  bind d i (Guard_C_Color cd c e) = getConstrList c ++ bind d i e
  lazyBind cd i C_Red = (i :=: ChooseN 0 0) : []
  lazyBind cd i C_Black = (i :=: ChooseN 1 0) : []
  lazyBind cd i C_DoublyBlack = (i :=: ChooseN 2 0) : []
  lazyBind d i (Choice_C_Color cd j x y) = [ConstraintChoice cd j (lazyBind d i
    x) (lazyBind d i y)]
  lazyBind d i (Choices_C_Color cd j@(FreeID _ _) xs) = lazyBindOrNarrow d i cd
    j xs
  lazyBind d i (Choices_C_Color cd j@(NarrowedID _ _) xs) = [ConstraintChoices
    cd j (map (lazyBind d i) xs)]
  lazyBind _ _ (Choices_C_Color cd i _) = error
    ("RedBlackTree.Color.lazyBind: Choices with ChoiceID: " ++ show i)
  lazyBind _ _ (Fail_C_Color cd info) = [Unsolvable info]
  lazyBind d i (Guard_C_Color cd c e) = getConstrList c ++ [i :=: LazyBind
    (lazyBind d i e)]

instance Curry C_Color where
  (=?=) (Choice_C_Color cd i x y) z d cs = narrow cd i ((=?=) x z d cs) ((=?=) y
    z d cs)
  (=?=) (Choices_C_Color cd i xs) y d cs = narrows cs cd i (\x -> (=?=) x y d
    cs) xs
  (=?=) (Guard_C_Color cd c e) y d cs = guardCons cd c ((=?=) e y d (addCs c
    cs))
  (=?=) (Fail_C_Color cd info) _ _ _ = failCons cd info
  (=?=) z (Choice_C_Color cd i x y) d cs = narrow cd i ((=?=) z x d cs) ((=?=) z
    y d cs)
  (=?=) y (Choices_C_Color cd i xs) d cs = narrows cs cd i (\x -> (=?=) y x d
    cs) xs
  (=?=) y (Guard_C_Color cd c e) d cs = guardCons cd c ((=?=) y e d (addCs c
    cs))
  (=?=) _ (Fail_C_Color cd info) _ _ = failCons cd info
  (=?=) C_Red C_Red d cs = C_True
  (=?=) C_Black C_Black d cs = C_True
  (=?=) C_DoublyBlack C_DoublyBlack d cs = C_True
  (=?=) _ _ d _ = C_False
  (<?=) (Choice_C_Color cd i x y) z d cs = narrow cd i ((<?=) x z d cs) ((<?=) y
    z d cs)
  (<?=) (Choices_C_Color cd i xs) y d cs = narrows cs cd i (\x -> (<?=) x y d
    cs) xs
  (<?=) (Guard_C_Color cd c e) y d cs = guardCons cd c ((<?=) e y d (addCs c
    cs))
  (<?=) (Fail_C_Color cd info) _ _ _ = failCons cd info
  (<?=) z (Choice_C_Color cd i x y) d cs = narrow cd i ((<?=) z x d cs) ((<?=) z
    y d cs)
  (<?=) y (Choices_C_Color cd i xs) d cs = narrows cs cd i (\x -> (<?=) y x d
    cs) xs
  (<?=) y (Guard_C_Color cd c e) d cs = guardCons cd c ((<?=) y e d (addCs c
    cs))
  (<?=) _ (Fail_C_Color cd info) _ _ = failCons cd info
  (<?=) C_Red C_Red d cs = C_True
  (<?=) C_Red C_Black _ _ = C_True
  (<?=) C_Red C_DoublyBlack _ _ = C_True
  (<?=) C_Black C_Black d cs = C_True
  (<?=) C_Black C_DoublyBlack _ _ = C_True
  (<?=) C_DoublyBlack C_DoublyBlack d cs = C_True
  (<?=) _ _ d _ = C_False

data C_Tree t0
  = C_Tree C_Color t0 (C_Tree t0) (C_Tree t0)
  | C_Empty
  | Choice_C_Tree Cover ID (C_Tree t0) (C_Tree t0)
  | Choices_C_Tree Cover ID [C_Tree t0]
  | Fail_C_Tree Cover FailInfo
  | Guard_C_Tree Cover Constraints (C_Tree t0)

instance (Show t0) => Show (C_Tree t0) where
  showsPrec d (Choice_C_Tree cd i x y) = showsChoice d cd i x y
  showsPrec d (Choices_C_Tree cd i xs) = showsChoices d cd i xs
  showsPrec d (Guard_C_Tree cd c e) = showsGuard d cd c e
  showsPrec _ (Fail_C_Tree cd info) = showChar '!'
  showsPrec _ (C_Tree x1 x2 x3 x4) = showString "(Tree" . (showChar ' ' . (shows
    x1 . (showChar ' ' . (shows x2 . (showChar ' ' . (shows x3 . (showChar ' ' .
    (shows x4 . showChar ')'))))))))
  showsPrec _ C_Empty = showString "Empty"

instance (Read t0) => Read (C_Tree t0) where
  readsPrec d s = readParen ((>) d 10) (\r -> [(C_Tree x1 x2 x3 x4, r4) | (_
    , r0) <- readQualified "RedBlackTree" "Tree" r, (x1, r1) <- readsPrec 11 r0,
    (x2, r2) <- readsPrec 11 r1, (x3, r3) <- readsPrec 11 r2, (x4, r4) <-
    readsPrec 11 r3]) s ++ readParen False (\r -> [(C_Empty, r0) | (_, r0) <-
    readQualified "RedBlackTree" "Empty" r]) s

instance NonDet (C_Tree t0) where
  choiceCons = Choice_C_Tree
  choicesCons = Choices_C_Tree
  failCons = Fail_C_Tree
  guardCons = Guard_C_Tree
  try (Choice_C_Tree cd i x y) = tryChoice cd i x y
  try (Choices_C_Tree cd i xs) = tryChoices cd i xs
  try (Fail_C_Tree cd info) = Fail cd info
  try (Guard_C_Tree cd c e) = Guard cd c e
  try x = Val x
  match f _ _ _ _ _ (Choice_C_Tree cd i x y) = f cd i x y
  match _ f _ _ _ _ (Choices_C_Tree cd i@(NarrowedID _ _) xs) = f cd i xs
  match _ _ f _ _ _ (Choices_C_Tree cd i@(FreeID _ _) xs) = f cd i xs
  match _ _ _ _ _ _ (Choices_C_Tree cd i _) = error
    ("RedBlackTree.Tree.match: Choices with ChoiceID " ++ show i)
  match _ _ _ f _ _ (Fail_C_Tree cd info) = f cd info
  match _ _ _ _ f _ (Guard_C_Tree cd c e) = f cd c e
  match _ _ _ _ _ f x = f x

instance (Generable t0) => Generable (C_Tree t0) where
  generate s c = Choices_C_Tree c (freeID [4, 0] s) [C_Tree (generate
    (leftSupply (leftSupply s)) c) (generate (rightSupply (leftSupply s)) c)
    (generate (leftSupply (rightSupply s)) c) (generate (rightSupply
    (rightSupply s)) c), C_Empty]

instance (NormalForm t0) => NormalForm (C_Tree t0) where
  ($!!) cont (C_Tree x1 x2 x3 x4) d cs = ($!!) (\y1 d cs -> ($!!) (\y2 d cs ->
    ($!!) (\y3 d cs -> ($!!) (\y4 d cs -> cont (C_Tree y1 y2 y3 y4) d cs) x4 d
    cs) x3 d cs) x2 d cs) x1 d cs
  ($!!) cont C_Empty d cs = cont C_Empty d cs
  ($!!) cont (Choice_C_Tree cd i x y) d cs = nfChoice cont cd i x y cd cs
  ($!!) cont (Choices_C_Tree cd i xs) d cs = nfChoices cont cd i xs d cs
  ($!!) cont (Guard_C_Tree cd c e) d cs = guardCons cd c (($!!) cont e d (addCs
    c cs))
  ($!!) _ (Fail_C_Tree cd info) _ _ = failCons cd info
  ($##) cont (C_Tree x1 x2 x3 x4) d cs = ($##) (\y1 d cs -> ($##) (\y2 d cs ->
    ($##) (\y3 d cs -> ($##) (\y4 d cs -> cont (C_Tree y1 y2 y3 y4) d cs) x4 d
    cs) x3 d cs) x2 d cs) x1 d cs
  ($##) cont C_Empty d cs = cont C_Empty d cs
  ($##) cont (Choice_C_Tree cd i x y) d cs = gnfChoice cont cd i x y cd cs
  ($##) cont (Choices_C_Tree cd i xs) d cs = gnfChoices cont cd i xs d cs
  ($##) cont (Guard_C_Tree cd c e) d cs = guardCons cd c (($##) cont e d (addCs
    c cs))
  ($##) _ (Fail_C_Tree cd info) _ _ = failCons cd info
  showCons (C_Tree _ _ _ _) = "RedBlackTree.Tree _ _ _ _"
  showCons C_Empty = "RedBlackTree.Empty"
  showCons x = error ("RedBlackTree.Tree.showCons: no constructor: " ++ show x)
  searchNF search cont (C_Tree x1 x2 x3 x4) = search (\y1 -> search (\y2 ->
    search (\y3 -> search (\y4 -> cont (C_Tree y1 y2 y3 y4)) x4) x3) x2) x1
  searchNF _ cont C_Empty = cont C_Empty
  searchNF _ _ x = error ("RedBlackTree.Tree.searchNF: no constructor: " ++ show
    x)

instance (Unifiable t0) => Unifiable (C_Tree t0) where
  (=.=) (C_Tree x1 x2 x3 x4) (C_Tree y1 y2 y3 y4) d cs = (&) ((=:=) x1 y1 d cs)
    ((&) ((=:=) x2 y2 d cs) ((&) ((=:=) x3 y3 d cs) ((=:=) x4 y4 d cs) d cs) d
    cs) d cs
  (=.=) C_Empty C_Empty d cs = C_True
  (=.=) a b cd _ = Fail_C_Bool cd (unificationFail (showCons a) (showCons b))
  (=.<=) (C_Tree x1 x2 x3 x4) (C_Tree y1 y2 y3 y4) d cs = (&) ((=:<=) x1 y1 d
    cs) ((&) ((=:<=) x2 y2 d cs) ((&) ((=:<=) x3 y3 d cs) ((=:<=) x4 y4 d cs) d
    cs) d cs) d cs
  (=.<=) C_Empty C_Empty d cs = C_True
  (=.<=) a b cd _ = Fail_C_Bool cd (unificationFail (showCons a) (showCons b))
  bind cd i (C_Tree x3 x4 x5 x6) = (i :=: ChooseN 0 4) : concat [bind cd (leftID
    (leftID i)) x3, bind cd (rightID (leftID i)) x4, bind cd (leftID (rightID
    i)) x5, bind cd (rightID (rightID i)) x6]
  bind cd i C_Empty = (i :=: ChooseN 1 0) : concat []
  bind d i (Choice_C_Tree cd j x y) = [ConstraintChoice cd j (bind d i x) (bind
    d i y)]
  bind d i (Choices_C_Tree cd j@(FreeID _ _) xs) = bindOrNarrow d i cd j xs
  bind d i (Choices_C_Tree cd j@(NarrowedID _ _) xs) = [ConstraintChoices cd j
    (map (bind d i) xs)]
  bind _ _ (Choices_C_Tree cd i _) = error
    ("RedBlackTree.Tree.bind: Choices with ChoiceID: " ++ show i)
  bind _ _ (Fail_C_Tree cd info) = [Unsolvable info]
  bind d i (Guard_C_Tree cd c e) = getConstrList c ++ bind d i e
  lazyBind cd i (C_Tree x3 x4 x5 x6) = (i :=: ChooseN 0 4) : [leftID (leftID
    i) :=: LazyBind (lazyBind cd (leftID (leftID i)) x3), rightID (leftID i) :=:
    LazyBind (lazyBind cd (rightID (leftID i)) x4), leftID (rightID i) :=:
    LazyBind (lazyBind cd (leftID (rightID i)) x5), rightID (rightID i) :=:
    LazyBind (lazyBind cd (rightID (rightID i)) x6)]
  lazyBind cd i C_Empty = (i :=: ChooseN 1 0) : []
  lazyBind d i (Choice_C_Tree cd j x y) = [ConstraintChoice cd j (lazyBind d i
    x) (lazyBind d i y)]
  lazyBind d i (Choices_C_Tree cd j@(FreeID _ _) xs) = lazyBindOrNarrow d i cd j
    xs
  lazyBind d i (Choices_C_Tree cd j@(NarrowedID _ _) xs) = [ConstraintChoices cd
    j (map (lazyBind d i) xs)]
  lazyBind _ _ (Choices_C_Tree cd i _) = error
    ("RedBlackTree.Tree.lazyBind: Choices with ChoiceID: " ++ show i)
  lazyBind _ _ (Fail_C_Tree cd info) = [Unsolvable info]
  lazyBind d i (Guard_C_Tree cd c e) = getConstrList c ++ [i :=: LazyBind
    (lazyBind d i e)]

instance (Curry t0) => Curry (C_Tree t0) where
  (=?=) (Choice_C_Tree cd i x y) z d cs = narrow cd i ((=?=) x z d cs) ((=?=) y
    z d cs)
  (=?=) (Choices_C_Tree cd i xs) y d cs = narrows cs cd i (\x -> (=?=) x y d cs)
    xs
  (=?=) (Guard_C_Tree cd c e) y d cs = guardCons cd c ((=?=) e y d (addCs c cs))
  (=?=) (Fail_C_Tree cd info) _ _ _ = failCons cd info
  (=?=) z (Choice_C_Tree cd i x y) d cs = narrow cd i ((=?=) z x d cs) ((=?=) z
    y d cs)
  (=?=) y (Choices_C_Tree cd i xs) d cs = narrows cs cd i (\x -> (=?=) y x d cs)
    xs
  (=?=) y (Guard_C_Tree cd c e) d cs = guardCons cd c ((=?=) y e d (addCs c cs))
  (=?=) _ (Fail_C_Tree cd info) _ _ = failCons cd info
  (=?=) (C_Tree x1 x2 x3 x4) (C_Tree y1 y2 y3 y4) d cs =
    Curry_Prelude.d_OP_amp_amp ((=?=) x1 y1 d cs) (Curry_Prelude.d_OP_amp_amp
    ((=?=) x2 y2 d cs) (Curry_Prelude.d_OP_amp_amp ((=?=) x3 y3 d cs) ((=?=) x4
    y4 d cs) d cs) d cs) d cs
  (=?=) C_Empty C_Empty d cs = C_True
  (=?=) _ _ d _ = C_False
  (<?=) (Choice_C_Tree cd i x y) z d cs = narrow cd i ((<?=) x z d cs) ((<?=) y
    z d cs)
  (<?=) (Choices_C_Tree cd i xs) y d cs = narrows cs cd i (\x -> (<?=) x y d cs)
    xs
  (<?=) (Guard_C_Tree cd c e) y d cs = guardCons cd c ((<?=) e y d (addCs c cs))
  (<?=) (Fail_C_Tree cd info) _ _ _ = failCons cd info
  (<?=) z (Choice_C_Tree cd i x y) d cs = narrow cd i ((<?=) z x d cs) ((<?=) z
    y d cs)
  (<?=) y (Choices_C_Tree cd i xs) d cs = narrows cs cd i (\x -> (<?=) y x d cs)
    xs
  (<?=) y (Guard_C_Tree cd c e) d cs = guardCons cd c ((<?=) y e d (addCs c cs))
  (<?=) _ (Fail_C_Tree cd info) _ _ = failCons cd info
  (<?=) (C_Tree x1 x2 x3 x4) (C_Tree y1 y2 y3 y4) d cs =
    Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x1 y1 d cs)
    (Curry_Prelude.d_OP_amp_amp ((=?=) x1 y1 d cs) (Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_OP_lt x2 y2 d cs) (Curry_Prelude.d_OP_amp_amp ((=?=) x2 y2
    d cs) (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x3 y3 d cs)
    (Curry_Prelude.d_OP_amp_amp ((=?=) x3 y3 d cs) ((<?=) x4 y4 d cs) d cs) d
    cs) d cs) d cs) d cs) d cs
  (<?=) (C_Tree _ _ _ _) C_Empty _ _ = C_True
  (<?=) C_Empty C_Empty d cs = C_True
  (<?=) _ _ d _ = C_False

d_C_empty :: forall t0 . (Curry_Prelude.Curry t0) => (t0 -> Cover -> ConstStore
  -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool) -> (t0 -> Cover
  -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool) -> (t0
  -> Cover -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> Cover -> ConstStore -> C_RedBlackTree t0
d_C_empty x1 x2 x3 cd cs = C_RedBlackTree x1 x2 x3 C_Empty

nd_C_empty :: forall t0 . (Curry_Prelude.Curry t0) => Func t0 (Func t0
  Curry_Prelude.C_Bool) -> Func t0 (Func t0 Curry_Prelude.C_Bool) -> Func t0
  (Func t0 Curry_Prelude.C_Bool) -> IDSupply -> Cover -> ConstStore
  -> C_RedBlackTree t0
nd_C_empty x1 x2 x3 s cd cs = HO_C_RedBlackTree x1 x2 x3 C_Empty

d_C_isEmpty :: forall t0 . (Curry_Prelude.Curry t0) => C_RedBlackTree t0
  -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_C_isEmpty x1 cd cs = case x1 of
  C_RedBlackTree x2 x3 x4 x5 -> d_C__case_177 x5 cd cs
  Choice_C_RedBlackTree d i l r -> narrow d i (d_C_isEmpty l cd cs) (d_C_isEmpty
    r cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> d_C_isEmpty z cd cs) xs
  Guard_C_RedBlackTree d c e -> guardCons d c (d_C_isEmpty e cd $! addCs c cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.isEmpty"
    [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.isEmpty" (showCons x1))

nd_C_isEmpty :: forall t0 . (Curry_Prelude.Curry t0) => C_RedBlackTree t0
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_Bool
nd_C_isEmpty x1 s cd cs = case x1 of
  HO_C_RedBlackTree x2 x3 x4 x5 -> d_C__case_177 x5 cd cs
  Choice_C_RedBlackTree d i l r -> narrow d i (nd_C_isEmpty l s cd cs)
    (nd_C_isEmpty r s cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> nd_C_isEmpty z s cd cs)
    xs
  Guard_C_RedBlackTree d c e -> guardCons d c (nd_C_isEmpty e s cd $! addCs c
    cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.isEmpty"
    [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.isEmpty" (showCons x1))

d_C_newTreeLike :: forall t0 . (Curry_Prelude.Curry t0) => C_RedBlackTree t0
  -> Cover -> ConstStore -> C_RedBlackTree t0
d_C_newTreeLike x1 cd cs = case x1 of
  C_RedBlackTree x2 x3 x4 x5 -> C_RedBlackTree x2 x3 x4 C_Empty
  Choice_C_RedBlackTree d i l r -> narrow d i (d_C_newTreeLike l cd cs)
    (d_C_newTreeLike r cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> d_C_newTreeLike z cd
    cs) xs
  Guard_C_RedBlackTree d c e -> guardCons d c (d_C_newTreeLike e cd $! addCs c
    cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.newTreeLike"
    [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.newTreeLike" (showCons x1))

nd_C_newTreeLike :: forall t0 . (Curry_Prelude.Curry t0) => C_RedBlackTree t0
  -> IDSupply -> Cover -> ConstStore -> C_RedBlackTree t0
nd_C_newTreeLike x1 s cd cs = case x1 of
  HO_C_RedBlackTree x2 x3 x4 x5 -> HO_C_RedBlackTree x2 x3 x4 C_Empty
  Choice_C_RedBlackTree d i l r -> narrow d i (nd_C_newTreeLike l s cd cs)
    (nd_C_newTreeLike r s cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> nd_C_newTreeLike z s cd
    cs) xs
  Guard_C_RedBlackTree d c e -> guardCons d c (nd_C_newTreeLike e s cd $! addCs
    c cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.newTreeLike"
    [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.newTreeLike" (showCons x1))

d_C_lookup :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_RedBlackTree t0
  -> Cover -> ConstStore -> Curry_Prelude.C_Maybe t0
d_C_lookup x1 x2 cd cs = case x2 of
  C_RedBlackTree x3 x4 x5 x6 -> d_C_lookupTree x4 x5 x1 x6 cd cs
  Choice_C_RedBlackTree d i l r -> narrow d i (d_C_lookup x1 l cd cs)
    (d_C_lookup x1 r cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> d_C_lookup x1 z cd cs)
    xs
  Guard_C_RedBlackTree d c e -> guardCons d c (d_C_lookup x1 e cd $! addCs c cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.lookup"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree.lookup" (showCons x2))

nd_C_lookup :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_RedBlackTree t0
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_Maybe t0
nd_C_lookup x1 x2 s cd cs = case x2 of
  HO_C_RedBlackTree x3 x4 x5 x6 -> let s0 = s
    in s0 `seq` nd_C_lookupTree x4 x5 x1 x6 s0 cd cs
  Choice_C_RedBlackTree d i l r -> narrow d i (nd_C_lookup x1 l s cd cs)
    (nd_C_lookup x1 r s cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> nd_C_lookup x1 z s cd
    cs) xs
  Guard_C_RedBlackTree d c e -> guardCons d c (nd_C_lookup x1 e s cd $! addCs c
    cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.lookup"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree.lookup" (showCons x2))

d_C_lookupTree :: forall t0 . (Curry_Prelude.Curry t0) => (t0 -> Cover
  -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool) -> (t0
  -> Cover -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> t0 -> C_Tree t0 -> Cover -> ConstStore -> Curry_Prelude.C_Maybe t0
d_C_lookupTree x1 x2 x3 x4 cd cs = case x4 of
  C_Empty -> Curry_Prelude.C_Nothing
  C_Tree x5 x6 x7 x8 -> d_C__case_176 x6 x3 x1 x2 x8 x7 (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_apply x1 x3 cd cs) x6 cd cs) cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C_lookupTree x1 x2 x3 l cd cs)
    (d_C_lookupTree x1 x2 x3 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C_lookupTree x1 x2 x3 z cd
    cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C_lookupTree x1 x2 x3 e cd $! addCs c
    cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.lookupTree" [show x1
    , show x2, show x3, show x4] info)
  _ -> failCons cd (consFail "RedBlackTree.lookupTree" (showCons x4))

nd_C_lookupTree :: forall t0 . (Curry_Prelude.Curry t0) => Func t0 (Func t0
  Curry_Prelude.C_Bool) -> Func t0 (Func t0 Curry_Prelude.C_Bool) -> t0
  -> C_Tree t0 -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_Maybe t0
nd_C_lookupTree x1 x2 x3 x4 s cd cs = case x4 of
  C_Empty -> Curry_Prelude.C_Nothing
  C_Tree x5 x6 x7 x8 -> let s4 = s
    in s4 `seq` (let s3 = leftSupply s4
                     s2 = rightSupply s4
    in s3 `seq` (s2 `seq` nd_C__case_176 x6 x3 x1 x2 x8 x7 (let s1 = leftSupply
                                                                  s2
                                                                s0 = rightSupply
                                                                  s2
    in s1 `seq` (s0 `seq` Curry_Prelude.nd_C_apply (Curry_Prelude.nd_C_apply x1
    x3 s0 cd cs) x6 s1 cd cs)) s3 cd cs))
  Choice_C_Tree d i l r -> narrow d i (nd_C_lookupTree x1 x2 x3 l s cd cs)
    (nd_C_lookupTree x1 x2 x3 r s cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> nd_C_lookupTree x1 x2 x3 z s cd
    cs) xs
  Guard_C_Tree d c e -> guardCons d c (nd_C_lookupTree x1 x2 x3 e s cd $! addCs
    c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.lookupTree" [show x1
    , show x2, show x3, show x4] info)
  _ -> failCons cd (consFail "RedBlackTree.lookupTree" (showCons x4))

d_C_update :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_RedBlackTree t0
  -> Cover -> ConstStore -> C_RedBlackTree t0
d_C_update x1 x2 cd cs = case x2 of
  C_RedBlackTree x3 x4 x5 x6 -> C_RedBlackTree x3 x4 x5 (d_C_updateTree x3 x5 x1
    x6 cd cs)
  Choice_C_RedBlackTree d i l r -> narrow d i (d_C_update x1 l cd cs)
    (d_C_update x1 r cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> d_C_update x1 z cd cs)
    xs
  Guard_C_RedBlackTree d c e -> guardCons d c (d_C_update x1 e cd $! addCs c cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.update"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree.update" (showCons x2))

nd_C_update :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_RedBlackTree t0
  -> IDSupply -> Cover -> ConstStore -> C_RedBlackTree t0
nd_C_update x1 x2 s cd cs = case x2 of
  HO_C_RedBlackTree x3 x4 x5 x6 -> let s0 = s
    in s0 `seq` HO_C_RedBlackTree x3 x4 x5 (nd_C_updateTree x3 x5 x1 x6 s0 cd
    cs)
  Choice_C_RedBlackTree d i l r -> narrow d i (nd_C_update x1 l s cd cs)
    (nd_C_update x1 r s cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> nd_C_update x1 z s cd
    cs) xs
  Guard_C_RedBlackTree d c e -> guardCons d c (nd_C_update x1 e s cd $! addCs c
    cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.update"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree.update" (showCons x2))

d_C_updateTree :: forall t0 . (Curry_Prelude.Curry t0) => (t0 -> Cover
  -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool) -> (t0
  -> Cover -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> t0 -> C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_C_updateTree x1 x2 x3 x4 cd cs = let x5 = d_OP_updateTree_dot_upd_dot_34 x3 x1
                                         x2 x4 cd cs
                                       x6 = d_OP_updateTree_dot_uscore_hash_selFP2_hash_e2
                                         x5 cd cs
                                       x7 = d_OP_updateTree_dot_uscore_hash_selFP3_hash_l
                                         x5 cd cs
                                       x8 = d_OP_updateTree_dot_uscore_hash_selFP4_hash_r
                                         x5 cd cs
  in C_Tree C_Black x6 x7 x8

nd_C_updateTree :: forall t0 . (Curry_Prelude.Curry t0) => Func t0 (Func t0
  Curry_Prelude.C_Bool) -> Func t0 (Func t0 Curry_Prelude.C_Bool) -> t0
  -> C_Tree t0 -> IDSupply -> Cover -> ConstStore -> C_Tree t0
nd_C_updateTree x1 x2 x3 x4 s cd cs = let s0 = s
  in s0 `seq` (let x5 = nd_OP_updateTree_dot_upd_dot_34 x3 x1 x2 x4 s0 cd cs
                   x6 = d_OP_updateTree_dot_uscore_hash_selFP2_hash_e2 x5 cd cs
                   x7 = d_OP_updateTree_dot_uscore_hash_selFP3_hash_l x5 cd cs
                   x8 = d_OP_updateTree_dot_uscore_hash_selFP4_hash_r x5 cd cs
  in C_Tree C_Black x6 x7 x8)

d_OP_updateTree_dot_upd_dot_34 :: forall t0 . (Curry_Prelude.Curry t0) => t0
  -> (t0 -> Cover -> ConstStore -> t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool) -> (t0 -> Cover -> ConstStore -> t0 -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool) -> C_Tree t0 -> Cover -> ConstStore
  -> C_Tree t0
d_OP_updateTree_dot_upd_dot_34 x1 x2 x3 x4 cd cs = case x4 of
  C_Empty -> C_Tree C_Red x1 C_Empty C_Empty
  C_Tree x5 x6 x7 x8 -> d_C__case_173 x6 x1 x2 x3 x8 x7 x5
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply x2 x1 cd cs) x6 cd cs) cd
    cs
  Choice_C_Tree d i l r -> narrow d i (d_OP_updateTree_dot_upd_dot_34 x1 x2 x3 l
    cd cs) (d_OP_updateTree_dot_upd_dot_34 x1 x2 x3 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_OP_updateTree_dot_upd_dot_34
    x1 x2 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_OP_updateTree_dot_upd_dot_34 x1 x2 x3 e
    cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.updateTree.upd.34"
    [show x1, show x2, show x3, show x4] info)
  _ -> failCons cd (consFail "RedBlackTree.updateTree.upd.34" (showCons x4))

nd_OP_updateTree_dot_upd_dot_34 :: forall t0 . (Curry_Prelude.Curry t0) => t0
  -> Func t0 (Func t0 Curry_Prelude.C_Bool) -> Func t0 (Func t0
  Curry_Prelude.C_Bool) -> C_Tree t0 -> IDSupply -> Cover -> ConstStore
  -> C_Tree t0
nd_OP_updateTree_dot_upd_dot_34 x1 x2 x3 x4 s cd cs = case x4 of
  C_Empty -> C_Tree C_Red x1 C_Empty C_Empty
  C_Tree x5 x6 x7 x8 -> let s4 = s
    in s4 `seq` (let s3 = leftSupply s4
                     s2 = rightSupply s4
    in s3 `seq` (s2 `seq` nd_C__case_173 x6 x1 x2 x3 x8 x7 x5
    (let s1 = leftSupply s2
         s0 = rightSupply s2
    in s1 `seq` (s0 `seq` Curry_Prelude.nd_C_apply (Curry_Prelude.nd_C_apply x2
    x1 s0 cd cs) x6 s1 cd cs)) s3 cd cs))
  Choice_C_Tree d i l r -> narrow d i (nd_OP_updateTree_dot_upd_dot_34 x1 x2 x3
    l s cd cs) (nd_OP_updateTree_dot_upd_dot_34 x1 x2 x3 r s cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> nd_OP_updateTree_dot_upd_dot_34
    x1 x2 x3 z s cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (nd_OP_updateTree_dot_upd_dot_34 x1 x2 x3
    e s cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.updateTree.upd.34"
    [show x1, show x2, show x3, show x4] info)
  _ -> failCons cd (consFail "RedBlackTree.updateTree.upd.34" (showCons x4))

d_OP_updateTree_dot_uscore_hash_selFP2_hash_e2 :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_updateTree_dot_uscore_hash_selFP2_hash_e2 x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> x3
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_updateTree_dot_uscore_hash_selFP2_hash_e2 l cd cs)
    (d_OP_updateTree_dot_uscore_hash_selFP2_hash_e2 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_updateTree_dot_uscore_hash_selFP2_hash_e2 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_updateTree_dot_uscore_hash_selFP2_hash_e2 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.updateTree._#selFP2#e2" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.updateTree._#selFP2#e2" (showCons
    x1))

d_OP_updateTree_dot_uscore_hash_selFP3_hash_l :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_updateTree_dot_uscore_hash_selFP3_hash_l x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> x4
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_updateTree_dot_uscore_hash_selFP3_hash_l l cd cs)
    (d_OP_updateTree_dot_uscore_hash_selFP3_hash_l r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_updateTree_dot_uscore_hash_selFP3_hash_l z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_updateTree_dot_uscore_hash_selFP3_hash_l e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.updateTree._#selFP3#l" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.updateTree._#selFP3#l" (showCons x1))

d_OP_updateTree_dot_uscore_hash_selFP4_hash_r :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_updateTree_dot_uscore_hash_selFP4_hash_r x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> x5
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_updateTree_dot_uscore_hash_selFP4_hash_r l cd cs)
    (d_OP_updateTree_dot_uscore_hash_selFP4_hash_r r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_updateTree_dot_uscore_hash_selFP4_hash_r z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_updateTree_dot_uscore_hash_selFP4_hash_r e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.updateTree._#selFP4#r" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.updateTree._#selFP4#r" (showCons x1))

d_C_delete :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_RedBlackTree t0
  -> Cover -> ConstStore -> C_RedBlackTree t0
d_C_delete x1 x2 cd cs = case x2 of
  C_RedBlackTree x3 x4 x5 x6 -> C_RedBlackTree x3 x4 x5
    (d_OP_delete_dot_blackenRoot_dot_43 (d_C_deleteTree x4 x5 x1 x6 cd cs) cd
    cs)
  Choice_C_RedBlackTree d i l r -> narrow d i (d_C_delete x1 l cd cs)
    (d_C_delete x1 r cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> d_C_delete x1 z cd cs)
    xs
  Guard_C_RedBlackTree d c e -> guardCons d c (d_C_delete x1 e cd $! addCs c cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.delete"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree.delete" (showCons x2))

nd_C_delete :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_RedBlackTree t0
  -> IDSupply -> Cover -> ConstStore -> C_RedBlackTree t0
nd_C_delete x1 x2 s cd cs = case x2 of
  HO_C_RedBlackTree x3 x4 x5 x6 -> let s0 = s
    in s0 `seq` HO_C_RedBlackTree x3 x4 x5 (d_OP_delete_dot_blackenRoot_dot_43
    (nd_C_deleteTree x4 x5 x1 x6 s0 cd cs) cd cs)
  Choice_C_RedBlackTree d i l r -> narrow d i (nd_C_delete x1 l s cd cs)
    (nd_C_delete x1 r s cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> nd_C_delete x1 z s cd
    cs) xs
  Guard_C_RedBlackTree d c e -> guardCons d c (nd_C_delete x1 e s cd $! addCs c
    cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.delete"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree.delete" (showCons x2))

d_OP_delete_dot_blackenRoot_dot_43 :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_delete_dot_blackenRoot_dot_43 x1 cd cs = case x1 of
  C_Empty -> C_Empty
  C_Tree x2 x3 x4 x5 -> C_Tree C_Black x3 x4 x5
  Choice_C_Tree d i l r -> narrow d i (d_OP_delete_dot_blackenRoot_dot_43 l cd
    cs) (d_OP_delete_dot_blackenRoot_dot_43 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_delete_dot_blackenRoot_dot_43 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_OP_delete_dot_blackenRoot_dot_43 e
    cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.delete.blackenRoot.43" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.delete.blackenRoot.43" (showCons x1))

d_C_deleteTree :: forall t0 . (Curry_Prelude.Curry t0) => (t0 -> Cover
  -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool) -> (t0
  -> Cover -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> t0 -> C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_C_deleteTree x1 x2 x3 x4 cd cs = case x4 of
  C_Empty -> C_Empty
  C_Tree x5 x6 x7 x8 -> d_C__case_170 x6 x3 x1 x2 x8 x7 x5
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply x1 x3 cd cs) x6 cd cs) cd
    cs
  Choice_C_Tree d i l r -> narrow d i (d_C_deleteTree x1 x2 x3 l cd cs)
    (d_C_deleteTree x1 x2 x3 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C_deleteTree x1 x2 x3 z cd
    cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C_deleteTree x1 x2 x3 e cd $! addCs c
    cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.deleteTree" [show x1
    , show x2, show x3, show x4] info)
  _ -> failCons cd (consFail "RedBlackTree.deleteTree" (showCons x4))

nd_C_deleteTree :: forall t0 . (Curry_Prelude.Curry t0) => Func t0 (Func t0
  Curry_Prelude.C_Bool) -> Func t0 (Func t0 Curry_Prelude.C_Bool) -> t0
  -> C_Tree t0 -> IDSupply -> Cover -> ConstStore -> C_Tree t0
nd_C_deleteTree x1 x2 x3 x4 s cd cs = case x4 of
  C_Empty -> C_Empty
  C_Tree x5 x6 x7 x8 -> let s4 = s
    in s4 `seq` (let s3 = leftSupply s4
                     s2 = rightSupply s4
    in s3 `seq` (s2 `seq` nd_C__case_170 x6 x3 x1 x2 x8 x7 x5
    (let s1 = leftSupply s2
         s0 = rightSupply s2
    in s1 `seq` (s0 `seq` Curry_Prelude.nd_C_apply (Curry_Prelude.nd_C_apply x1
    x3 s0 cd cs) x6 s1 cd cs)) s3 cd cs))
  Choice_C_Tree d i l r -> narrow d i (nd_C_deleteTree x1 x2 x3 l s cd cs)
    (nd_C_deleteTree x1 x2 x3 r s cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> nd_C_deleteTree x1 x2 x3 z s cd
    cs) xs
  Guard_C_Tree d c e -> guardCons d c (nd_C_deleteTree x1 x2 x3 e s cd $! addCs
    c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.deleteTree" [show x1
    , show x2, show x3, show x4] info)
  _ -> failCons cd (consFail "RedBlackTree.deleteTree" (showCons x4))

d_OP_deleteTree_dot_addColor_dot_55 :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Color -> C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_deleteTree_dot_addColor_dot_55 x1 x2 cd cs = case x1 of
  C_DoublyBlack -> x2
  C_Red -> x2
  C_Black -> d_C__case_165 x2 cd cs
  Choice_C_Color d i l r -> narrow d i (d_OP_deleteTree_dot_addColor_dot_55 l x2
    cd cs) (d_OP_deleteTree_dot_addColor_dot_55 r x2 cd cs)
  Choices_C_Color d i xs -> narrows cs d i (\z ->
    d_OP_deleteTree_dot_addColor_dot_55 z x2 cd cs) xs
  Guard_C_Color d c e -> guardCons d c (d_OP_deleteTree_dot_addColor_dot_55 e x2
    cd $! addCs c cs)
  Fail_C_Color d info -> failCons d (traceFail
    "RedBlackTree.deleteTree.addColor.55" [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree.deleteTree.addColor.55" (showCons
    x1))

d_OP_deleteTree_dot_rightMost_dot_55 :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_deleteTree_dot_rightMost_dot_55 x1 cd cs = case x1 of
  C_Empty -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "RedBlackTree.rightMost") cd cs
  C_Tree x2 x3 x4 x5 -> d_C__case_163 x5 x3 (d_C_isEmptyTree x5 cd cs) cd cs
  Choice_C_Tree d i l r -> narrow d i (d_OP_deleteTree_dot_rightMost_dot_55 l cd
    cs) (d_OP_deleteTree_dot_rightMost_dot_55 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_deleteTree_dot_rightMost_dot_55 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_OP_deleteTree_dot_rightMost_dot_55 e
    cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.deleteTree.rightMost.55" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.deleteTree.rightMost.55" (showCons
    x1))

d_C_tree2list :: forall t0 . (Curry_Prelude.Curry t0) => C_RedBlackTree t0
  -> Cover -> ConstStore -> Curry_Prelude.OP_List t0
d_C_tree2list x1 cd cs = case x1 of
  C_RedBlackTree x2 x3 x4 x5 -> d_C_tree2listTree x5 cd cs
  Choice_C_RedBlackTree d i l r -> narrow d i (d_C_tree2list l cd cs)
    (d_C_tree2list r cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> d_C_tree2list z cd cs)
    xs
  Guard_C_RedBlackTree d c e -> guardCons d c (d_C_tree2list e cd $! addCs c cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.tree2list"
    [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.tree2list" (showCons x1))

nd_C_tree2list :: forall t0 . (Curry_Prelude.Curry t0) => C_RedBlackTree t0
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.OP_List t0
nd_C_tree2list x1 s cd cs = case x1 of
  HO_C_RedBlackTree x2 x3 x4 x5 -> d_C_tree2listTree x5 cd cs
  Choice_C_RedBlackTree d i l r -> narrow d i (nd_C_tree2list l s cd cs)
    (nd_C_tree2list r s cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> nd_C_tree2list z s cd
    cs) xs
  Guard_C_RedBlackTree d c e -> guardCons d c (nd_C_tree2list e s cd $! addCs c
    cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.tree2list"
    [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.tree2list" (showCons x1))

d_C_tree2listTree :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> Curry_Prelude.OP_List t0
d_C_tree2listTree x1 cd cs = d_OP_tree2listTree_dot_t2l_dot_82 x1
  Curry_Prelude.OP_List cd cs

d_OP_tree2listTree_dot_t2l_dot_82 :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Curry_Prelude.OP_List t0 -> Cover -> ConstStore
  -> Curry_Prelude.OP_List t0
d_OP_tree2listTree_dot_t2l_dot_82 x1 x2 cd cs = case x1 of
  C_Empty -> x2
  C_Tree x3 x4 x5 x6 -> d_OP_tree2listTree_dot_t2l_dot_82 x5
    (Curry_Prelude.OP_Cons x4 (d_OP_tree2listTree_dot_t2l_dot_82 x6 x2 cd cs))
    cd cs
  Choice_C_Tree d i l r -> narrow d i (d_OP_tree2listTree_dot_t2l_dot_82 l x2 cd
    cs) (d_OP_tree2listTree_dot_t2l_dot_82 r x2 cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_tree2listTree_dot_t2l_dot_82 z x2 cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_OP_tree2listTree_dot_t2l_dot_82 e x2
    cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.tree2listTree.t2l.82" [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree.tree2listTree.t2l.82" (showCons x1))

d_C_sortBy :: forall t0 . (Curry_Prelude.Curry t0) => (t0 -> Cover -> ConstStore
  -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool) -> Curry_Prelude.OP_List
  t0 -> Cover -> ConstStore -> Curry_Prelude.OP_List t0
d_C_sortBy x1 x2 cd cs = d_C_tree2list (Curry_Prelude.d_C_foldr (acceptCs id
  d_C_update) (d_C_empty (acceptCs id d_OP_sortBy_dot_uscore_hash_lambda1)
  (acceptCs id Curry_Prelude.d_OP_eq_eq) x1 cd cs) x2 cd cs) cd cs

nd_C_sortBy :: forall t0 . (Curry_Prelude.Curry t0) => Func t0 (Func t0
  Curry_Prelude.C_Bool) -> Curry_Prelude.OP_List t0 -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.OP_List t0
nd_C_sortBy x1 x2 s cd cs = let s4 = s
  in s4 `seq` (let s3 = leftSupply s4
                   s2 = rightSupply s4
  in s3 `seq` (s2 `seq` nd_C_tree2list (let s1 = leftSupply s2
                                            s0 = rightSupply s2
  in s1 `seq` (s0 `seq` Curry_Prelude.nd_C_foldr (wrapDX (wrapNX id) (acceptCs
  id nd_C_update)) (nd_C_empty (wrapDX (wrapDX id) (acceptCs id
  d_OP_sortBy_dot_uscore_hash_lambda1)) (wrapDX (wrapDX id) (acceptCs id
  Curry_Prelude.d_OP_eq_eq)) x1 s0 cd cs) x2 s1 cd cs)) s3 cd cs))

d_OP_sortBy_dot_uscore_hash_lambda1 :: forall t0 . (Curry_Prelude.Curry
  t0) => t0 -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_OP_sortBy_dot_uscore_hash_lambda1 x1 x2 cd cs = Curry_Prelude.C_False

d_C_setInsertEquivalence :: forall t0 . (Curry_Prelude.Curry t0) => (t0 -> Cover
  -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> C_RedBlackTree t0 -> Cover -> ConstStore -> C_RedBlackTree t0
d_C_setInsertEquivalence x1 x2 cd cs = case x2 of
  C_RedBlackTree x3 x4 x5 x6 -> C_RedBlackTree x1 x4 x5 x6
  Choice_C_RedBlackTree d i l r -> narrow d i (d_C_setInsertEquivalence x1 l cd
    cs) (d_C_setInsertEquivalence x1 r cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z ->
    d_C_setInsertEquivalence x1 z cd cs) xs
  Guard_C_RedBlackTree d c e -> guardCons d c (d_C_setInsertEquivalence x1 e
    cd $! addCs c cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail
    "RedBlackTree.setInsertEquivalence" [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree.setInsertEquivalence" (showCons x2))

nd_C_setInsertEquivalence :: forall t0 . (Curry_Prelude.Curry t0) => Func t0
  (Func t0 Curry_Prelude.C_Bool) -> C_RedBlackTree t0 -> IDSupply -> Cover
  -> ConstStore -> C_RedBlackTree t0
nd_C_setInsertEquivalence x1 x2 s cd cs = case x2 of
  HO_C_RedBlackTree x3 x4 x5 x6 -> HO_C_RedBlackTree x1 x4 x5 x6
  Choice_C_RedBlackTree d i l r -> narrow d i (nd_C_setInsertEquivalence x1 l s
    cd cs) (nd_C_setInsertEquivalence x1 r s cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z ->
    nd_C_setInsertEquivalence x1 z s cd cs) xs
  Guard_C_RedBlackTree d c e -> guardCons d c (nd_C_setInsertEquivalence x1 e s
    cd $! addCs c cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail
    "RedBlackTree.setInsertEquivalence" [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree.setInsertEquivalence" (showCons x2))

d_C_rbt :: forall t0 . (Curry_Prelude.Curry t0) => C_RedBlackTree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C_rbt x1 cd cs = case x1 of
  C_RedBlackTree x2 x3 x4 x5 -> x5
  Choice_C_RedBlackTree d i l r -> narrow d i (d_C_rbt l cd cs) (d_C_rbt r cd
    cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> d_C_rbt z cd cs) xs
  Guard_C_RedBlackTree d c e -> guardCons d c (d_C_rbt e cd $! addCs c cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.rbt" [show
    x1] info)
  _ -> failCons cd (consFail "RedBlackTree.rbt" (showCons x1))

nd_C_rbt :: forall t0 . (Curry_Prelude.Curry t0) => C_RedBlackTree t0
  -> IDSupply -> Cover -> ConstStore -> C_Tree t0
nd_C_rbt x1 s cd cs = case x1 of
  HO_C_RedBlackTree x2 x3 x4 x5 -> x5
  Choice_C_RedBlackTree d i l r -> narrow d i (nd_C_rbt l s cd cs) (nd_C_rbt r s
    cd cs)
  Choices_C_RedBlackTree d i xs -> narrows cs d i (\z -> nd_C_rbt z s cd cs) xs
  Guard_C_RedBlackTree d c e -> guardCons d c (nd_C_rbt e s cd $! addCs c cs)
  Fail_C_RedBlackTree d info -> failCons d (traceFail "RedBlackTree.rbt" [show
    x1] info)
  _ -> failCons cd (consFail "RedBlackTree.rbt" (showCons x1))

d_C_isEmptyTree :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isEmptyTree x1 cd cs = case x1 of
  C_Empty -> Curry_Prelude.C_True
  C_Tree x2 x3 x4 x5 -> Curry_Prelude.C_False
  Choice_C_Tree d i l r -> narrow d i (d_C_isEmptyTree l cd cs) (d_C_isEmptyTree
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C_isEmptyTree z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C_isEmptyTree e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.isEmptyTree" [show
    x1] info)
  _ -> failCons cd (consFail "RedBlackTree.isEmptyTree" (showCons x1))

d_C_isBlack :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isBlack x1 cd cs = case x1 of
  C_Empty -> Curry_Prelude.C_True
  C_Tree x2 x3 x4 x5 -> Curry_Prelude.d_OP_eq_eq x2 C_Black cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C_isBlack l cd cs) (d_C_isBlack r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C_isBlack z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C_isBlack e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.isBlack" [show x1]
    info)
  _ -> failCons cd (consFail "RedBlackTree.isBlack" (showCons x1))

d_C_isRed :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isRed x1 cd cs = case x1 of
  C_Empty -> Curry_Prelude.C_False
  C_Tree x2 x3 x4 x5 -> Curry_Prelude.d_OP_eq_eq x2 C_Red cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C_isRed l cd cs) (d_C_isRed r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C_isRed z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C_isRed e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.isRed" [show x1]
    info)
  _ -> failCons cd (consFail "RedBlackTree.isRed" (showCons x1))

d_C_isDoublyBlack :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isDoublyBlack x1 cd cs = case x1 of
  C_Empty -> Curry_Prelude.C_True
  C_Tree x2 x3 x4 x5 -> Curry_Prelude.d_OP_eq_eq x2 C_DoublyBlack cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C_isDoublyBlack l cd cs)
    (d_C_isDoublyBlack r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C_isDoublyBlack z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C_isDoublyBlack e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.isDoublyBlack" [show
    x1] info)
  _ -> failCons cd (consFail "RedBlackTree.isDoublyBlack" (showCons x1))

d_C_left :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C_left x1 cd cs = case x1 of
  C_Empty -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "RedBlackTree.left") cd cs
  C_Tree x2 x3 x4 x5 -> x4
  Choice_C_Tree d i l r -> narrow d i (d_C_left l cd cs) (d_C_left r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C_left z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C_left e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.left" [show x1]
    info)
  _ -> failCons cd (consFail "RedBlackTree.left" (showCons x1))

d_C_right :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C_right x1 cd cs = case x1 of
  C_Empty -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "RedBlackTree.right") cd cs
  C_Tree x2 x3 x4 x5 -> x5
  Choice_C_Tree d i l r -> narrow d i (d_C_right l cd cs) (d_C_right r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C_right z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C_right e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.right" [show x1]
    info)
  _ -> failCons cd (consFail "RedBlackTree.right" (showCons x1))

d_C_singleBlack :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C_singleBlack x1 cd cs = case x1 of
  C_Empty -> C_Empty
  C_Tree x2 x3 x4 x5 -> d_C__case_162 x5 x4 x3 x2 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C_singleBlack l cd cs) (d_C_singleBlack
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C_singleBlack z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C_singleBlack e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.singleBlack" [show
    x1] info)
  _ -> failCons cd (consFail "RedBlackTree.singleBlack" (showCons x1))

d_C_balanceL :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C_balanceL x1 cd cs = let x2 = d_C_left x1 cd cs
  in d_C__case_161 x2 x1 (Curry_Prelude.d_OP_amp_amp (d_C_isRed x2 cd cs)
  (d_C_isRed (d_C_left x2 cd cs) cd cs) cd cs) cd cs

d_OP_balanceL_dot_uscore_hash_selFP6_hash_z :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_balanceL_dot_uscore_hash_selFP6_hash_z x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_158 x3 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP6_hash_z l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP6_hash_z r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP6_hash_z z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP6_hash_z e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.balanceL._#selFP6#z"
    [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP6#z" (showCons x1))

d_OP_balanceL_dot_uscore_hash_selFP7_hash_y :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_balanceL_dot_uscore_hash_selFP7_hash_y x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_156 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP7_hash_y l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP7_hash_y r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP7_hash_y z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP7_hash_y e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.balanceL._#selFP7#y"
    [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP7#y" (showCons x1))

d_OP_balanceL_dot_uscore_hash_selFP8_hash_x :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_balanceL_dot_uscore_hash_selFP8_hash_x x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_154 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP8_hash_x l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP8_hash_x r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP8_hash_x z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP8_hash_x e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.balanceL._#selFP8#x"
    [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP8#x" (showCons x1))

d_OP_balanceL_dot_uscore_hash_selFP9_hash_a :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceL_dot_uscore_hash_selFP9_hash_a x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_152 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP9_hash_a l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP9_hash_a r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP9_hash_a z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP9_hash_a e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree.balanceL._#selFP9#a"
    [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP9#a" (showCons x1))

d_OP_balanceL_dot_uscore_hash_selFP10_hash_b :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceL_dot_uscore_hash_selFP10_hash_b x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_150 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP10_hash_b l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP10_hash_b r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP10_hash_b z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP10_hash_b e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceL._#selFP10#b" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP10#b" (showCons x1))

d_OP_balanceL_dot_uscore_hash_selFP11_hash_c :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceL_dot_uscore_hash_selFP11_hash_c x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_148 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP11_hash_c l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP11_hash_c r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP11_hash_c z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP11_hash_c e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceL._#selFP11#c" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP11#c" (showCons x1))

d_OP_balanceL_dot_uscore_hash_selFP12_hash_d :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceL_dot_uscore_hash_selFP12_hash_d x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_146 x5 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP12_hash_d l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP12_hash_d r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP12_hash_d z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP12_hash_d e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceL._#selFP12#d" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP12#d" (showCons x1))

d_OP_balanceL_dot_uscore_hash_selFP14_hash_z :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_balanceL_dot_uscore_hash_selFP14_hash_z x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_144 x3 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP14_hash_z l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP14_hash_z r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP14_hash_z z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP14_hash_z e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceL._#selFP14#z" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP14#z" (showCons x1))

d_OP_balanceL_dot_uscore_hash_selFP15_hash_x :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_balanceL_dot_uscore_hash_selFP15_hash_x x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_142 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP15_hash_x l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP15_hash_x r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP15_hash_x z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP15_hash_x e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceL._#selFP15#x" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP15#x" (showCons x1))

d_OP_balanceL_dot_uscore_hash_selFP16_hash_a :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceL_dot_uscore_hash_selFP16_hash_a x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_140 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP16_hash_a l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP16_hash_a r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP16_hash_a z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP16_hash_a e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceL._#selFP16#a" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP16#a" (showCons x1))

d_OP_balanceL_dot_uscore_hash_selFP17_hash_y :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_balanceL_dot_uscore_hash_selFP17_hash_y x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_138 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP17_hash_y l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP17_hash_y r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP17_hash_y z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP17_hash_y e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceL._#selFP17#y" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP17#y" (showCons x1))

d_OP_balanceL_dot_uscore_hash_selFP18_hash_b :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceL_dot_uscore_hash_selFP18_hash_b x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_136 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP18_hash_b l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP18_hash_b r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP18_hash_b z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP18_hash_b e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceL._#selFP18#b" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP18#b" (showCons x1))

d_OP_balanceL_dot_uscore_hash_selFP19_hash_c :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceL_dot_uscore_hash_selFP19_hash_c x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_134 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP19_hash_c l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP19_hash_c r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP19_hash_c z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP19_hash_c e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceL._#selFP19#c" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP19#c" (showCons x1))

d_OP_balanceL_dot_uscore_hash_selFP20_hash_d :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceL_dot_uscore_hash_selFP20_hash_d x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_132 x5 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceL_dot_uscore_hash_selFP20_hash_d l cd cs)
    (d_OP_balanceL_dot_uscore_hash_selFP20_hash_d r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceL_dot_uscore_hash_selFP20_hash_d z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceL_dot_uscore_hash_selFP20_hash_d e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceL._#selFP20#d" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceL._#selFP20#d" (showCons x1))

d_C_balanceR :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C_balanceR x1 cd cs = let x2 = d_C_right x1 cd cs
  in d_C__case_130 x2 x1 (Curry_Prelude.d_OP_amp_amp (d_C_isRed x2 cd cs)
  (d_C_isRed (d_C_right x2 cd cs) cd cs) cd cs) cd cs

d_OP_balanceR_dot_uscore_hash_selFP22_hash_x :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_balanceR_dot_uscore_hash_selFP22_hash_x x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_127 x3 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP22_hash_x l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP22_hash_x r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP22_hash_x z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP22_hash_x e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP22#x" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP22#x" (showCons x1))

d_OP_balanceR_dot_uscore_hash_selFP23_hash_a :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceR_dot_uscore_hash_selFP23_hash_a x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_125 x4 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP23_hash_a l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP23_hash_a r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP23_hash_a z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP23_hash_a e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP23#a" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP23#a" (showCons x1))

d_OP_balanceR_dot_uscore_hash_selFP24_hash_y :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_balanceR_dot_uscore_hash_selFP24_hash_y x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_123 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP24_hash_y l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP24_hash_y r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP24_hash_y z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP24_hash_y e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP24#y" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP24#y" (showCons x1))

d_OP_balanceR_dot_uscore_hash_selFP25_hash_b :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceR_dot_uscore_hash_selFP25_hash_b x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_121 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP25_hash_b l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP25_hash_b r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP25_hash_b z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP25_hash_b e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP25#b" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP25#b" (showCons x1))

d_OP_balanceR_dot_uscore_hash_selFP26_hash_z :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_balanceR_dot_uscore_hash_selFP26_hash_z x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_119 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP26_hash_z l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP26_hash_z r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP26_hash_z z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP26_hash_z e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP26#z" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP26#z" (showCons x1))

d_OP_balanceR_dot_uscore_hash_selFP27_hash_c :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceR_dot_uscore_hash_selFP27_hash_c x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_117 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP27_hash_c l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP27_hash_c r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP27_hash_c z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP27_hash_c e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP27#c" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP27#c" (showCons x1))

d_OP_balanceR_dot_uscore_hash_selFP28_hash_d :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceR_dot_uscore_hash_selFP28_hash_d x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_115 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP28_hash_d l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP28_hash_d r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP28_hash_d z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP28_hash_d e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP28#d" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP28#d" (showCons x1))

d_OP_balanceR_dot_uscore_hash_selFP30_hash_x :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_balanceR_dot_uscore_hash_selFP30_hash_x x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_113 x3 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP30_hash_x l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP30_hash_x r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP30_hash_x z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP30_hash_x e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP30#x" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP30#x" (showCons x1))

d_OP_balanceR_dot_uscore_hash_selFP31_hash_a :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceR_dot_uscore_hash_selFP31_hash_a x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_111 x4 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP31_hash_a l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP31_hash_a r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP31_hash_a z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP31_hash_a e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP31#a" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP31#a" (showCons x1))

d_OP_balanceR_dot_uscore_hash_selFP32_hash_z :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_balanceR_dot_uscore_hash_selFP32_hash_z x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_109 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP32_hash_z l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP32_hash_z r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP32_hash_z z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP32_hash_z e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP32#z" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP32#z" (showCons x1))

d_OP_balanceR_dot_uscore_hash_selFP33_hash_y :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_balanceR_dot_uscore_hash_selFP33_hash_y x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_107 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP33_hash_y l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP33_hash_y r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP33_hash_y z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP33_hash_y e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP33#y" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP33#y" (showCons x1))

d_OP_balanceR_dot_uscore_hash_selFP34_hash_b :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceR_dot_uscore_hash_selFP34_hash_b x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_105 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP34_hash_b l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP34_hash_b r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP34_hash_b z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP34_hash_b e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP34#b" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP34#b" (showCons x1))

d_OP_balanceR_dot_uscore_hash_selFP35_hash_c :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceR_dot_uscore_hash_selFP35_hash_c x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_103 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP35_hash_c l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP35_hash_c r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP35_hash_c z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP35_hash_c e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP35#c" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP35#c" (showCons x1))

d_OP_balanceR_dot_uscore_hash_selFP36_hash_d :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_balanceR_dot_uscore_hash_selFP36_hash_d x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_101 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_balanceR_dot_uscore_hash_selFP36_hash_d l cd cs)
    (d_OP_balanceR_dot_uscore_hash_selFP36_hash_d r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_balanceR_dot_uscore_hash_selFP36_hash_d z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_balanceR_dot_uscore_hash_selFP36_hash_d e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.balanceR._#selFP36#d" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.balanceR._#selFP36#d" (showCons x1))

d_C_delBalanceL :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C_delBalanceL x1 cd cs = d_C__case_99 x1 (d_C_isDoublyBlack (d_C_left x1 cd
  cs) cd cs) cd cs

d_C_reviseLeft :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C_reviseLeft x1 cd cs = let x2 = d_C_right x1 cd cs
                              x3 = d_C_isBlack x2 cd cs
  in d_C__case_98 x2 x3 x1 (d_C_isEmptyTree x2 cd cs) cd cs

d_OP_reviseLeft_dot_uscore_hash_selFP38_hash_col :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Color
d_OP_reviseLeft_dot_uscore_hash_selFP38_hash_col x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_92 x2 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP38_hash_col l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP38_hash_col r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP38_hash_col z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP38_hash_col e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP38#col" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP38#col" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP39_hash_x :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseLeft_dot_uscore_hash_selFP39_hash_x x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_90 x3 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP39_hash_x l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP39_hash_x r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP39_hash_x z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP39_hash_x e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP39#x" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP39#x" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP40_hash_a :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP40_hash_a x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_88 x4 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP40_hash_a l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP40_hash_a r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP40_hash_a z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP40_hash_a e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP40#a" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP40#a" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP41_hash_z :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseLeft_dot_uscore_hash_selFP41_hash_z x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_86 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP41_hash_z l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP41_hash_z r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP41_hash_z z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP41_hash_z e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP41#z" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP41#z" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP42_hash_y :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseLeft_dot_uscore_hash_selFP42_hash_y x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_84 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP42_hash_y l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP42_hash_y r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP42_hash_y z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP42_hash_y e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP42#y" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP42#y" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP43_hash_b :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP43_hash_b x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_82 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP43_hash_b l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP43_hash_b r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP43_hash_b z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP43_hash_b e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP43#b" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP43#b" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP44_hash_c :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP44_hash_c x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_80 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP44_hash_c l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP44_hash_c r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP44_hash_c z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP44_hash_c e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP44#c" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP44#c" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP45_hash_d :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP45_hash_d x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_78 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP45_hash_d l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP45_hash_d r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP45_hash_d z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP45_hash_d e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP45#d" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP45#d" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP47_hash_col :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Color
d_OP_reviseLeft_dot_uscore_hash_selFP47_hash_col x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_76 x2 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP47_hash_col l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP47_hash_col r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP47_hash_col z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP47_hash_col e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP47#col" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP47#col" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP48_hash_x :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseLeft_dot_uscore_hash_selFP48_hash_x x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_74 x3 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP48_hash_x l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP48_hash_x r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP48_hash_x z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP48_hash_x e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP48#x" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP48#x" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP49_hash_a :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP49_hash_a x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_72 x4 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP49_hash_a l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP49_hash_a r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP49_hash_a z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP49_hash_a e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP49#a" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP49#a" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP50_hash_y :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseLeft_dot_uscore_hash_selFP50_hash_y x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_70 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP50_hash_y l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP50_hash_y r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP50_hash_y z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP50_hash_y e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP50#y" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP50#y" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP51_hash_b :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP51_hash_b x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_68 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP51_hash_b l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP51_hash_b r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP51_hash_b z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP51_hash_b e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP51#b" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP51#b" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP52_hash_z :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseLeft_dot_uscore_hash_selFP52_hash_z x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_66 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP52_hash_z l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP52_hash_z r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP52_hash_z z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP52_hash_z e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP52#z" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP52#z" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP53_hash_c :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP53_hash_c x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_64 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP53_hash_c l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP53_hash_c r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP53_hash_c z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP53_hash_c e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP53#c" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP53#c" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP54_hash_d :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP54_hash_d x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_62 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP54_hash_d l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP54_hash_d r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP54_hash_d z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP54_hash_d e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP54#d" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP54#d" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP56_hash_col :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Color
d_OP_reviseLeft_dot_uscore_hash_selFP56_hash_col x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_60 x2 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP56_hash_col l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP56_hash_col r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP56_hash_col z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP56_hash_col e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP56#col" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP56#col" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP57_hash_x :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseLeft_dot_uscore_hash_selFP57_hash_x x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_59 x3 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP57_hash_x l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP57_hash_x r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP57_hash_x z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP57_hash_x e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP57#x" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP57#x" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP58_hash_a :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP58_hash_a x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_58 x4 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP58_hash_a l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP58_hash_a r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP58_hash_a z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP58_hash_a e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP58#a" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP58#a" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP59_hash_y :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseLeft_dot_uscore_hash_selFP59_hash_y x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_57 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP59_hash_y l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP59_hash_y r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP59_hash_y z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP59_hash_y e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP59#y" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP59#y" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP60_hash_b :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP60_hash_b x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_56 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP60_hash_b l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP60_hash_b r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP60_hash_b z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP60_hash_b e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP60#b" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP60#b" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP61_hash_c :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP61_hash_c x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_55 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP61_hash_c l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP61_hash_c r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP61_hash_c z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP61_hash_c e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP61#c" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP61#c" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP63_hash_x :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseLeft_dot_uscore_hash_selFP63_hash_x x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_54 x3 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP63_hash_x l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP63_hash_x r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP63_hash_x z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP63_hash_x e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP63#x" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP63#x" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP64_hash_a :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP64_hash_a x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_53 x4 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP64_hash_a l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP64_hash_a r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP64_hash_a z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP64_hash_a e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP64#a" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP64#a" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP65_hash_y :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseLeft_dot_uscore_hash_selFP65_hash_y x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_52 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP65_hash_y l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP65_hash_y r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP65_hash_y z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP65_hash_y e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP65#y" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP65#y" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP66_hash_b :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP66_hash_b x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_51 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP66_hash_b l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP66_hash_b r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP66_hash_b z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP66_hash_b e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP66#b" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP66#b" (showCons
    x1))

d_OP_reviseLeft_dot_uscore_hash_selFP67_hash_c :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseLeft_dot_uscore_hash_selFP67_hash_c x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_50 x5 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseLeft_dot_uscore_hash_selFP67_hash_c l cd cs)
    (d_OP_reviseLeft_dot_uscore_hash_selFP67_hash_c r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseLeft_dot_uscore_hash_selFP67_hash_c z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseLeft_dot_uscore_hash_selFP67_hash_c e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseLeft._#selFP67#c" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseLeft._#selFP67#c" (showCons
    x1))

d_C_delBalanceR :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C_delBalanceR x1 cd cs = d_C__case_49 x1 (d_C_isDoublyBlack (d_C_right x1 cd
  cs) cd cs) cd cs

d_C_reviseRight :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C_reviseRight x1 cd cs = let x2 = d_C_left x1 cd cs
                               x3 = d_C_isBlack x2 cd cs
  in d_C__case_48 x2 x3 x1 (d_C_isEmptyTree x2 cd cs) cd cs

d_OP_reviseRight_dot_uscore_hash_selFP69_hash_col :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Color
d_OP_reviseRight_dot_uscore_hash_selFP69_hash_col x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_42 x2 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP69_hash_col l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP69_hash_col r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP69_hash_col z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP69_hash_col e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP69#col" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP69#col" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP70_hash_x :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseRight_dot_uscore_hash_selFP70_hash_x x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_40 x3 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP70_hash_x l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP70_hash_x r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP70_hash_x z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP70_hash_x e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP70#x" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP70#x" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP71_hash_y :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseRight_dot_uscore_hash_selFP71_hash_y x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_38 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP71_hash_y l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP71_hash_y r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP71_hash_y z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP71_hash_y e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP71#y" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP71#y" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP72_hash_z :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseRight_dot_uscore_hash_selFP72_hash_z x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_36 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP72_hash_z l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP72_hash_z r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP72_hash_z z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP72_hash_z e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP72#z" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP72#z" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP73_hash_d :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP73_hash_d x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_34 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP73_hash_d l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP73_hash_d r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP73_hash_d z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP73_hash_d e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP73#d" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP73#d" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP74_hash_c :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP74_hash_c x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_32 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP74_hash_c l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP74_hash_c r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP74_hash_c z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP74_hash_c e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP74#c" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP74#c" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP75_hash_b :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP75_hash_b x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_30 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP75_hash_b l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP75_hash_b r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP75_hash_b z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP75_hash_b e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP75#b" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP75#b" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP76_hash_a :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP76_hash_a x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_28 x5 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP76_hash_a l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP76_hash_a r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP76_hash_a z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP76_hash_a e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP76#a" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP76#a" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP78_hash_col :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Color
d_OP_reviseRight_dot_uscore_hash_selFP78_hash_col x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_26 x2 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP78_hash_col l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP78_hash_col r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP78_hash_col z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP78_hash_col e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP78#col" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP78#col" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP79_hash_x :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseRight_dot_uscore_hash_selFP79_hash_x x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_24 x3 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP79_hash_x l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP79_hash_x r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP79_hash_x z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP79_hash_x e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP79#x" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP79#x" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP80_hash_z :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseRight_dot_uscore_hash_selFP80_hash_z x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_22 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP80_hash_z l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP80_hash_z r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP80_hash_z z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP80_hash_z e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP80#z" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP80#z" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP81_hash_d :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP81_hash_d x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_20 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP81_hash_d l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP81_hash_d r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP81_hash_d z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP81_hash_d e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP81#d" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP81#d" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP82_hash_y :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseRight_dot_uscore_hash_selFP82_hash_y x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_18 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP82_hash_y l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP82_hash_y r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP82_hash_y z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP82_hash_y e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP82#y" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP82#y" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP83_hash_c :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP83_hash_c x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_16 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP83_hash_c l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP83_hash_c r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP83_hash_c z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP83_hash_c e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP83#c" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP83#c" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP84_hash_b :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP84_hash_b x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_14 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP84_hash_b l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP84_hash_b r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP84_hash_b z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP84_hash_b e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP84#b" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP84#b" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP85_hash_a :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP85_hash_a x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_12 x5 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP85_hash_a l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP85_hash_a r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP85_hash_a z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP85_hash_a e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP85#a" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP85#a" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP87_hash_col :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Color
d_OP_reviseRight_dot_uscore_hash_selFP87_hash_col x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_10 x2 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP87_hash_col l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP87_hash_col r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP87_hash_col z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP87_hash_col e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP87#col" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP87#col" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP88_hash_x :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseRight_dot_uscore_hash_selFP88_hash_x x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_9 x3 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP88_hash_x l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP88_hash_x r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP88_hash_x z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP88_hash_x e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP88#x" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP88#x" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP89_hash_y :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseRight_dot_uscore_hash_selFP89_hash_y x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_8 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP89_hash_y l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP89_hash_y r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP89_hash_y z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP89_hash_y e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP89#y" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP89#y" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP90_hash_c :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP90_hash_c x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_7 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP90_hash_c l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP90_hash_c r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP90_hash_c z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP90_hash_c e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP90#c" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP90#c" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP91_hash_b :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP91_hash_b x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_6 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP91_hash_b l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP91_hash_b r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP91_hash_b z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP91_hash_b e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP91#b" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP91#b" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP92_hash_a :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP92_hash_a x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_5 x5 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP92_hash_a l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP92_hash_a r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP92_hash_a z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP92_hash_a e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP92#a" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP92#a" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP94_hash_x :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseRight_dot_uscore_hash_selFP94_hash_x x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_4 x3 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP94_hash_x l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP94_hash_x r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP94_hash_x z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP94_hash_x e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP94#x" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP94#x" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP95_hash_y :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> t0
d_OP_reviseRight_dot_uscore_hash_selFP95_hash_y x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_3 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP95_hash_y l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP95_hash_y r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP95_hash_y z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP95_hash_y e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP95#y" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP95#y" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP96_hash_c :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP96_hash_c x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_2 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP96_hash_c l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP96_hash_c r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP96_hash_c z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP96_hash_c e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP96#c" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP96#c" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP97_hash_b :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP97_hash_b x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_1 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP97_hash_b l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP97_hash_b r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP97_hash_b z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP97_hash_b e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP97#b" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP97#b" (showCons
    x1))

d_OP_reviseRight_dot_uscore_hash_selFP98_hash_a :: forall t0 . (Curry_Prelude.Curry
  t0) => C_Tree t0 -> Cover -> ConstStore -> C_Tree t0
d_OP_reviseRight_dot_uscore_hash_selFP98_hash_a x1 cd cs = case x1 of
  C_Tree x2 x3 x4 x5 -> d_C__case_0 x5 x4 cd cs
  Choice_C_Tree d i l r -> narrow d i
    (d_OP_reviseRight_dot_uscore_hash_selFP98_hash_a l cd cs)
    (d_OP_reviseRight_dot_uscore_hash_selFP98_hash_a r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z ->
    d_OP_reviseRight_dot_uscore_hash_selFP98_hash_a z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c
    (d_OP_reviseRight_dot_uscore_hash_selFP98_hash_a e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail
    "RedBlackTree.reviseRight._#selFP98#a" [show x1] info)
  _ -> failCons cd (consFail "RedBlackTree.reviseRight._#selFP98#a" (showCons
    x1))

d_C__case_0 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_0 x5 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> x5
  Choice_C_Tree d i l r -> narrow d i (d_C__case_0 x5 l cd cs) (d_C__case_0 x5 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_0 x5 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_0 x5 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_0" [show x5
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_0" (showCons x4))

d_C__case_1 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_1 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> x9
  Choice_C_Tree d i l r -> narrow d i (d_C__case_1 l cd cs) (d_C__case_1 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_1 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_1 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_1" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_1" (showCons x4))

d_C__case_2 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_2 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> x8
  Choice_C_Tree d i l r -> narrow d i (d_C__case_2 l cd cs) (d_C__case_2 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_2 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_2 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_2" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_2" (showCons x4))

d_C__case_3 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_3 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> x7
  Choice_C_Tree d i l r -> narrow d i (d_C__case_3 l cd cs) (d_C__case_3 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_3" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_3" (showCons x4))

d_C__case_4 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_4 x3 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> x3
  Choice_C_Tree d i l r -> narrow d i (d_C__case_4 x3 l cd cs) (d_C__case_4 x3 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_4 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_4 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_4" [show x3
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_4" (showCons x4))

d_C__case_5 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_5 x5 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> x5
  Choice_C_Tree d i l r -> narrow d i (d_C__case_5 x5 l cd cs) (d_C__case_5 x5 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_5 x5 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_5 x5 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_5" [show x5
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_5" (showCons x4))

d_C__case_6 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_6 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> x9
  Choice_C_Tree d i l r -> narrow d i (d_C__case_6 l cd cs) (d_C__case_6 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_6 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_6 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_6" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_6" (showCons x4))

d_C__case_7 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_7 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> x8
  Choice_C_Tree d i l r -> narrow d i (d_C__case_7 l cd cs) (d_C__case_7 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_7 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_7 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_7" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_7" (showCons x4))

d_C__case_8 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_8 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> x7
  Choice_C_Tree d i l r -> narrow d i (d_C__case_8 l cd cs) (d_C__case_8 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_8 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_8 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_8" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_8" (showCons x4))

d_C__case_9 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_9 x3 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> x3
  Choice_C_Tree d i l r -> narrow d i (d_C__case_9 x3 l cd cs) (d_C__case_9 x3 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_9 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_9 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_9" [show x3
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_9" (showCons x4))

d_C__case_10 :: forall t0 . (Curry_Prelude.Curry t0) => C_Color -> C_Tree t0
  -> Cover -> ConstStore -> C_Color
d_C__case_10 x2 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> x2
  Choice_C_Tree d i l r -> narrow d i (d_C__case_10 x2 l cd cs) (d_C__case_10 x2
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_10 x2 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_10 x2 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_10" [show x2
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_10" (showCons x4))

d_C__case_12 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_12 x5 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_11 x5 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_12 x5 l cd cs) (d_C__case_12 x5
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_12 x5 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_12 x5 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_12" [show x5
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_12" (showCons x4))

d_C__case_11 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_11 x5 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x5
  Choice_C_Tree d i l r -> narrow d i (d_C__case_11 x5 l cd cs) (d_C__case_11 x5
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_11 x5 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_11 x5 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_11" [show x5
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_11" (showCons x9))

d_C__case_14 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_14 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_13 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_14 l cd cs) (d_C__case_14 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_14 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_14 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_14" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_14" (showCons x4))

d_C__case_13 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_13 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x13
  Choice_C_Tree d i l r -> narrow d i (d_C__case_13 l cd cs) (d_C__case_13 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_13 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_13 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_13" [show x9]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_13" (showCons x9))

d_C__case_16 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_16 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_15 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_16 l cd cs) (d_C__case_16 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_16 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_16 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_16" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_16" (showCons x4))

d_C__case_15 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_15 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x12
  Choice_C_Tree d i l r -> narrow d i (d_C__case_15 l cd cs) (d_C__case_15 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_15 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_15 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_15" [show x9]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_15" (showCons x9))

d_C__case_18 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_18 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_17 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_18 l cd cs) (d_C__case_18 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_18 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_18 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_18" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_18" (showCons x4))

d_C__case_17 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_17 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x11
  Choice_C_Tree d i l r -> narrow d i (d_C__case_17 l cd cs) (d_C__case_17 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_17 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_17 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_17" [show x9]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_17" (showCons x9))

d_C__case_20 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_20 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_19 x8 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_20 l cd cs) (d_C__case_20 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_20 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_20 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_20" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_20" (showCons x4))

d_C__case_19 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_19 x8 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x8
  Choice_C_Tree d i l r -> narrow d i (d_C__case_19 x8 l cd cs) (d_C__case_19 x8
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_19 x8 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_19 x8 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_19" [show x8
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_19" (showCons x9))

d_C__case_22 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_22 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_21 x7 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_22 l cd cs) (d_C__case_22 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_22 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_22 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_22" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_22" (showCons x4))

d_C__case_21 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_21 x7 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x7
  Choice_C_Tree d i l r -> narrow d i (d_C__case_21 x7 l cd cs) (d_C__case_21 x7
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_21 x7 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_21 x7 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_21" [show x7
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_21" (showCons x9))

d_C__case_24 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_24 x3 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_23 x3 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_24 x3 l cd cs) (d_C__case_24 x3
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_24 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_24 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_24" [show x3
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_24" (showCons x4))

d_C__case_23 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_23 x3 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x3
  Choice_C_Tree d i l r -> narrow d i (d_C__case_23 x3 l cd cs) (d_C__case_23 x3
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_23 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_23 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_23" [show x3
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_23" (showCons x9))

d_C__case_26 :: forall t0 . (Curry_Prelude.Curry t0) => C_Color -> C_Tree t0
  -> Cover -> ConstStore -> C_Color
d_C__case_26 x2 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_25 x2 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_26 x2 l cd cs) (d_C__case_26 x2
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_26 x2 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_26 x2 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_26" [show x2
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_26" (showCons x4))

d_C__case_25 :: forall t0 . (Curry_Prelude.Curry t0) => C_Color -> C_Tree t0
  -> Cover -> ConstStore -> C_Color
d_C__case_25 x2 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x2
  Choice_C_Tree d i l r -> narrow d i (d_C__case_25 x2 l cd cs) (d_C__case_25 x2
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_25 x2 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_25 x2 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_25" [show x2
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_25" (showCons x9))

d_C__case_28 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_28 x5 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_27 x5 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_28 x5 l cd cs) (d_C__case_28 x5
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_28 x5 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_28 x5 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_28" [show x5
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_28" (showCons x4))

d_C__case_27 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_27 x5 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x5
  Choice_C_Tree d i l r -> narrow d i (d_C__case_27 x5 l cd cs) (d_C__case_27 x5
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_27 x5 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_27 x5 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_27" [show x5
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_27" (showCons x8))

d_C__case_30 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_30 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_29 x9 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_30 l cd cs) (d_C__case_30 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_30 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_30 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_30" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_30" (showCons x4))

d_C__case_29 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_29 x9 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x9
  Choice_C_Tree d i l r -> narrow d i (d_C__case_29 x9 l cd cs) (d_C__case_29 x9
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_29 x9 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_29 x9 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_29" [show x9
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_29" (showCons x8))

d_C__case_32 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_32 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_31 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_32 l cd cs) (d_C__case_32 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_32 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_32 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_32" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_32" (showCons x4))

d_C__case_31 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_31 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x13
  Choice_C_Tree d i l r -> narrow d i (d_C__case_31 l cd cs) (d_C__case_31 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_31 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_31 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_31" [show x8]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_31" (showCons x8))

d_C__case_34 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_34 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_33 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_34 l cd cs) (d_C__case_34 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_34 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_34 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_34" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_34" (showCons x4))

d_C__case_33 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_33 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x12
  Choice_C_Tree d i l r -> narrow d i (d_C__case_33 l cd cs) (d_C__case_33 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_33 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_33 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_33" [show x8]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_33" (showCons x8))

d_C__case_36 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_36 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_35 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_36 l cd cs) (d_C__case_36 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_36 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_36 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_36" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_36" (showCons x4))

d_C__case_35 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_35 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x11
  Choice_C_Tree d i l r -> narrow d i (d_C__case_35 l cd cs) (d_C__case_35 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_35 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_35 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_35" [show x8]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_35" (showCons x8))

d_C__case_38 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_38 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_37 x7 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_38 l cd cs) (d_C__case_38 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_38 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_38 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_38" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_38" (showCons x4))

d_C__case_37 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_37 x7 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x7
  Choice_C_Tree d i l r -> narrow d i (d_C__case_37 x7 l cd cs) (d_C__case_37 x7
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_37 x7 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_37 x7 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_37" [show x7
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_37" (showCons x8))

d_C__case_40 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_40 x3 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_39 x3 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_40 x3 l cd cs) (d_C__case_40 x3
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_40 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_40 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_40" [show x3
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_40" (showCons x4))

d_C__case_39 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_39 x3 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x3
  Choice_C_Tree d i l r -> narrow d i (d_C__case_39 x3 l cd cs) (d_C__case_39 x3
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_39 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_39 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_39" [show x3
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_39" (showCons x8))

d_C__case_42 :: forall t0 . (Curry_Prelude.Curry t0) => C_Color -> C_Tree t0
  -> Cover -> ConstStore -> C_Color
d_C__case_42 x2 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_41 x2 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_42 x2 l cd cs) (d_C__case_42 x2
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_42 x2 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_42 x2 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_42" [show x2
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_42" (showCons x4))

d_C__case_41 :: forall t0 . (Curry_Prelude.Curry t0) => C_Color -> C_Tree t0
  -> Cover -> ConstStore -> C_Color
d_C__case_41 x2 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x2
  Choice_C_Tree d i l r -> narrow d i (d_C__case_41 x2 l cd cs) (d_C__case_41 x2
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_41 x2 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_41 x2 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_41" [show x2
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_41" (showCons x8))

d_C__case_48 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> C_Tree t0 -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_48 x2 x3 x1 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> x1
  Curry_Prelude.C_False -> d_C__case_47 x2 x3 x1 (Curry_Prelude.d_OP_amp_amp x3
    (d_C_isRed (d_C_left x2 cd cs) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_48 x2 x3 x1 l cd
    cs) (d_C__case_48 x2 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_48 x2
    x3 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_48 x2 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_48" [show x2, show x3, show x1, show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_48" (showCons x4))

d_C__case_47 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> C_Tree t0 -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_47 x2 x3 x1 x12 cd cs = case x12 of
  Curry_Prelude.C_True -> let x4 = d_OP_reviseRight_dot_uscore_hash_selFP69_hash_col
                                x1 cd cs
                              x5 = d_OP_reviseRight_dot_uscore_hash_selFP70_hash_x
                                x1 cd cs
                              x6 = d_OP_reviseRight_dot_uscore_hash_selFP71_hash_y
                                x1 cd cs
                              x7 = d_OP_reviseRight_dot_uscore_hash_selFP72_hash_z
                                x1 cd cs
                              x8 = d_OP_reviseRight_dot_uscore_hash_selFP73_hash_d
                                x1 cd cs
                              x9 = d_OP_reviseRight_dot_uscore_hash_selFP74_hash_c
                                x1 cd cs
                              x10 = d_OP_reviseRight_dot_uscore_hash_selFP75_hash_b
                                x1 cd cs
                              x11 = d_OP_reviseRight_dot_uscore_hash_selFP76_hash_a
                                x1 cd cs
    in C_Tree x4 x6 (C_Tree C_Black x7 x8 x9) (C_Tree C_Black x5 x10
    (d_C_singleBlack x11 cd cs))
  Curry_Prelude.C_False -> d_C__case_46 x2 x3 x1 (Curry_Prelude.d_OP_amp_amp x3
    (d_C_isRed (d_C_right x2 cd cs) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_47 x2 x3 x1 l cd
    cs) (d_C__case_47 x2 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_47 x2
    x3 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_47 x2 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_47" [show x2, show x3, show x1, show x12] info)
  _ -> failCons cd (consFail "RedBlackTree._case_47" (showCons x12))

d_C__case_46 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> C_Tree t0 -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_46 x2 x3 x1 x20 cd cs = case x20 of
  Curry_Prelude.C_True -> let x12 = d_OP_reviseRight_dot_uscore_hash_selFP78_hash_col
                                x1 cd cs
                              x13 = d_OP_reviseRight_dot_uscore_hash_selFP79_hash_x
                                x1 cd cs
                              x14 = d_OP_reviseRight_dot_uscore_hash_selFP80_hash_z
                                x1 cd cs
                              x15 = d_OP_reviseRight_dot_uscore_hash_selFP81_hash_d
                                x1 cd cs
                              x16 = d_OP_reviseRight_dot_uscore_hash_selFP82_hash_y
                                x1 cd cs
                              x17 = d_OP_reviseRight_dot_uscore_hash_selFP83_hash_c
                                x1 cd cs
                              x18 = d_OP_reviseRight_dot_uscore_hash_selFP84_hash_b
                                x1 cd cs
                              x19 = d_OP_reviseRight_dot_uscore_hash_selFP85_hash_a
                                x1 cd cs
    in C_Tree x12 x16 (C_Tree C_Black x14 x15 x17) (C_Tree C_Black x13 x18
    (d_C_singleBlack x19 cd cs))
  Curry_Prelude.C_False -> d_C__case_45 x1 x3 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_46 x2 x3 x1 l cd
    cs) (d_C__case_46 x2 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_46 x2
    x3 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_46 x2 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_46" [show x2, show x3, show x1, show x20] info)
  _ -> failCons cd (consFail "RedBlackTree._case_46" (showCons x20))

d_C__case_45 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_45 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> let x20 = d_OP_reviseRight_dot_uscore_hash_selFP87_hash_col
                                x1 cd cs
                              x21 = d_OP_reviseRight_dot_uscore_hash_selFP88_hash_x
                                x1 cd cs
                              x22 = d_OP_reviseRight_dot_uscore_hash_selFP89_hash_y
                                x1 cd cs
                              x23 = d_OP_reviseRight_dot_uscore_hash_selFP90_hash_c
                                x1 cd cs
                              x24 = d_OP_reviseRight_dot_uscore_hash_selFP91_hash_b
                                x1 cd cs
                              x25 = d_OP_reviseRight_dot_uscore_hash_selFP92_hash_a
                                x1 cd cs
    in C_Tree (d_C__case_44 x20 (Curry_Prelude.d_OP_eq_eq x20 C_Red cd cs) cd
    cs) x21 (C_Tree C_Red x22 x23 x24) (d_C_singleBlack x25 cd cs)
  Curry_Prelude.C_False -> d_C__case_43 x1 (Curry_Prelude.d_C_otherwise cd cs)
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_45 x1 l cd cs)
    (d_C__case_45 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_45 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_45 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_45" [show x1, show x3] info)
  _ -> failCons cd (consFail "RedBlackTree._case_45" (showCons x3))

d_C__case_43 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_43 x1 x31 cd cs = case x31 of
  Curry_Prelude.C_True -> let x26 = d_OP_reviseRight_dot_uscore_hash_selFP94_hash_x
                                x1 cd cs
                              x27 = d_OP_reviseRight_dot_uscore_hash_selFP95_hash_y
                                x1 cd cs
                              x28 = d_OP_reviseRight_dot_uscore_hash_selFP96_hash_c
                                x1 cd cs
                              x29 = d_OP_reviseRight_dot_uscore_hash_selFP97_hash_b
                                x1 cd cs
                              x30 = d_OP_reviseRight_dot_uscore_hash_selFP98_hash_a
                                x1 cd cs
    in C_Tree C_Black x27 x28 (d_C_reviseRight (C_Tree C_Red x26 x29 x30) cd cs)
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_43 x1 l cd cs)
    (d_C__case_43 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_43 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_43 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_43" [show x1, show x31] info)
  _ -> failCons cd (consFail "RedBlackTree._case_43" (showCons x31))

d_C__case_44 :: C_Color -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> C_Color
d_C__case_44 x20 x21 cd cs = case x21 of
  Curry_Prelude.C_True -> C_Black
  Curry_Prelude.C_False -> C_DoublyBlack
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_44 x20 l cd cs)
    (d_C__case_44 x20 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_44 x20
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_44 x20 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_44" [show x20, show x21] info)
  _ -> failCons cd (consFail "RedBlackTree._case_44" (showCons x21))

d_C__case_49 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_49 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> d_C_reviseRight x1 cd cs
  Curry_Prelude.C_False -> x1
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_49 x1 l cd cs)
    (d_C__case_49 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_49 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_49 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_49" [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree._case_49" (showCons x2))

d_C__case_50 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_50 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> x9
  Choice_C_Tree d i l r -> narrow d i (d_C__case_50 l cd cs) (d_C__case_50 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_50 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_50 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_50" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_50" (showCons x5))

d_C__case_51 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_51 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> x8
  Choice_C_Tree d i l r -> narrow d i (d_C__case_51 l cd cs) (d_C__case_51 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_51 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_51 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_51" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_51" (showCons x5))

d_C__case_52 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_52 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> x7
  Choice_C_Tree d i l r -> narrow d i (d_C__case_52 l cd cs) (d_C__case_52 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_52 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_52 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_52" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_52" (showCons x5))

d_C__case_53 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_53 x4 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> x4
  Choice_C_Tree d i l r -> narrow d i (d_C__case_53 x4 l cd cs) (d_C__case_53 x4
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_53 x4 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_53 x4 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_53" [show x4
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_53" (showCons x5))

d_C__case_54 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_54 x3 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> x3
  Choice_C_Tree d i l r -> narrow d i (d_C__case_54 x3 l cd cs) (d_C__case_54 x3
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_54 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_54 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_54" [show x3
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_54" (showCons x5))

d_C__case_55 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_55 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> x9
  Choice_C_Tree d i l r -> narrow d i (d_C__case_55 l cd cs) (d_C__case_55 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_55 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_55 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_55" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_55" (showCons x5))

d_C__case_56 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_56 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> x8
  Choice_C_Tree d i l r -> narrow d i (d_C__case_56 l cd cs) (d_C__case_56 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_56 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_56 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_56" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_56" (showCons x5))

d_C__case_57 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_57 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> x7
  Choice_C_Tree d i l r -> narrow d i (d_C__case_57 l cd cs) (d_C__case_57 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_57 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_57 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_57" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_57" (showCons x5))

d_C__case_58 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_58 x4 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> x4
  Choice_C_Tree d i l r -> narrow d i (d_C__case_58 x4 l cd cs) (d_C__case_58 x4
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_58 x4 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_58 x4 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_58" [show x4
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_58" (showCons x5))

d_C__case_59 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_59 x3 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> x3
  Choice_C_Tree d i l r -> narrow d i (d_C__case_59 x3 l cd cs) (d_C__case_59 x3
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_59 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_59 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_59" [show x3
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_59" (showCons x5))

d_C__case_60 :: forall t0 . (Curry_Prelude.Curry t0) => C_Color -> C_Tree t0
  -> Cover -> ConstStore -> C_Color
d_C__case_60 x2 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> x2
  Choice_C_Tree d i l r -> narrow d i (d_C__case_60 x2 l cd cs) (d_C__case_60 x2
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_60 x2 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_60 x2 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_60" [show x2
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_60" (showCons x5))

d_C__case_62 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_62 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_61 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_62 l cd cs) (d_C__case_62 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_62 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_62 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_62" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_62" (showCons x5))

d_C__case_61 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_61 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x13
  Choice_C_Tree d i l r -> narrow d i (d_C__case_61 l cd cs) (d_C__case_61 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_61 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_61 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_61" [show x9]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_61" (showCons x9))

d_C__case_64 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_64 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_63 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_64 l cd cs) (d_C__case_64 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_64 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_64 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_64" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_64" (showCons x5))

d_C__case_63 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_63 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x12
  Choice_C_Tree d i l r -> narrow d i (d_C__case_63 l cd cs) (d_C__case_63 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_63 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_63 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_63" [show x9]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_63" (showCons x9))

d_C__case_66 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_66 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_65 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_66 l cd cs) (d_C__case_66 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_66 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_66 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_66" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_66" (showCons x5))

d_C__case_65 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_65 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x11
  Choice_C_Tree d i l r -> narrow d i (d_C__case_65 l cd cs) (d_C__case_65 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_65 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_65 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_65" [show x9]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_65" (showCons x9))

d_C__case_68 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_68 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_67 x8 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_68 l cd cs) (d_C__case_68 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_68 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_68 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_68" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_68" (showCons x5))

d_C__case_67 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_67 x8 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x8
  Choice_C_Tree d i l r -> narrow d i (d_C__case_67 x8 l cd cs) (d_C__case_67 x8
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_67 x8 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_67 x8 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_67" [show x8
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_67" (showCons x9))

d_C__case_70 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_70 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_69 x7 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_70 l cd cs) (d_C__case_70 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_70 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_70 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_70" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_70" (showCons x5))

d_C__case_69 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_69 x7 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x7
  Choice_C_Tree d i l r -> narrow d i (d_C__case_69 x7 l cd cs) (d_C__case_69 x7
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_69 x7 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_69 x7 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_69" [show x7
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_69" (showCons x9))

d_C__case_72 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_72 x4 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_71 x4 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_72 x4 l cd cs) (d_C__case_72 x4
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_72 x4 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_72 x4 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_72" [show x4
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_72" (showCons x5))

d_C__case_71 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_71 x4 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x4
  Choice_C_Tree d i l r -> narrow d i (d_C__case_71 x4 l cd cs) (d_C__case_71 x4
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_71 x4 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_71 x4 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_71" [show x4
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_71" (showCons x9))

d_C__case_74 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_74 x3 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_73 x3 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_74 x3 l cd cs) (d_C__case_74 x3
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_74 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_74 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_74" [show x3
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_74" (showCons x5))

d_C__case_73 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_73 x3 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x3
  Choice_C_Tree d i l r -> narrow d i (d_C__case_73 x3 l cd cs) (d_C__case_73 x3
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_73 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_73 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_73" [show x3
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_73" (showCons x9))

d_C__case_76 :: forall t0 . (Curry_Prelude.Curry t0) => C_Color -> C_Tree t0
  -> Cover -> ConstStore -> C_Color
d_C__case_76 x2 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_75 x2 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_76 x2 l cd cs) (d_C__case_76 x2
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_76 x2 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_76 x2 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_76" [show x2
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_76" (showCons x5))

d_C__case_75 :: forall t0 . (Curry_Prelude.Curry t0) => C_Color -> C_Tree t0
  -> Cover -> ConstStore -> C_Color
d_C__case_75 x2 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x2
  Choice_C_Tree d i l r -> narrow d i (d_C__case_75 x2 l cd cs) (d_C__case_75 x2
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_75 x2 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_75 x2 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_75" [show x2
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_75" (showCons x9))

d_C__case_78 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_78 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_77 x9 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_78 l cd cs) (d_C__case_78 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_78 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_78 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_78" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_78" (showCons x5))

d_C__case_77 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_77 x9 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x9
  Choice_C_Tree d i l r -> narrow d i (d_C__case_77 x9 l cd cs) (d_C__case_77 x9
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_77 x9 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_77 x9 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_77" [show x9
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_77" (showCons x8))

d_C__case_80 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_80 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_79 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_80 l cd cs) (d_C__case_80 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_80 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_80 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_80" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_80" (showCons x5))

d_C__case_79 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_79 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x13
  Choice_C_Tree d i l r -> narrow d i (d_C__case_79 l cd cs) (d_C__case_79 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_79 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_79 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_79" [show x8]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_79" (showCons x8))

d_C__case_82 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_82 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_81 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_82 l cd cs) (d_C__case_82 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_82 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_82 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_82" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_82" (showCons x5))

d_C__case_81 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_81 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x12
  Choice_C_Tree d i l r -> narrow d i (d_C__case_81 l cd cs) (d_C__case_81 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_81 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_81 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_81" [show x8]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_81" (showCons x8))

d_C__case_84 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_84 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_83 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_84 l cd cs) (d_C__case_84 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_84 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_84 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_84" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_84" (showCons x5))

d_C__case_83 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_83 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x11
  Choice_C_Tree d i l r -> narrow d i (d_C__case_83 l cd cs) (d_C__case_83 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_83 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_83 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_83" [show x8]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_83" (showCons x8))

d_C__case_86 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_86 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_85 x7 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_86 l cd cs) (d_C__case_86 r cd
    cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_86 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_86 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_86" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_86" (showCons x5))

d_C__case_85 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_85 x7 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x7
  Choice_C_Tree d i l r -> narrow d i (d_C__case_85 x7 l cd cs) (d_C__case_85 x7
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_85 x7 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_85 x7 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_85" [show x7
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_85" (showCons x8))

d_C__case_88 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_88 x4 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_87 x4 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_88 x4 l cd cs) (d_C__case_88 x4
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_88 x4 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_88 x4 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_88" [show x4
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_88" (showCons x5))

d_C__case_87 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_87 x4 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x4
  Choice_C_Tree d i l r -> narrow d i (d_C__case_87 x4 l cd cs) (d_C__case_87 x4
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_87 x4 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_87 x4 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_87" [show x4
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_87" (showCons x8))

d_C__case_90 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_90 x3 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_89 x3 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_90 x3 l cd cs) (d_C__case_90 x3
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_90 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_90 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_90" [show x3
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_90" (showCons x5))

d_C__case_89 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_89 x3 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x3
  Choice_C_Tree d i l r -> narrow d i (d_C__case_89 x3 l cd cs) (d_C__case_89 x3
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_89 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_89 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_89" [show x3
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_89" (showCons x8))

d_C__case_92 :: forall t0 . (Curry_Prelude.Curry t0) => C_Color -> C_Tree t0
  -> Cover -> ConstStore -> C_Color
d_C__case_92 x2 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_91 x2 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_92 x2 l cd cs) (d_C__case_92 x2
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_92 x2 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_92 x2 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_92" [show x2
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_92" (showCons x5))

d_C__case_91 :: forall t0 . (Curry_Prelude.Curry t0) => C_Color -> C_Tree t0
  -> Cover -> ConstStore -> C_Color
d_C__case_91 x2 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x2
  Choice_C_Tree d i l r -> narrow d i (d_C__case_91 x2 l cd cs) (d_C__case_91 x2
    r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_91 x2 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_91 x2 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_91" [show x2
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_91" (showCons x8))

d_C__case_98 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> C_Tree t0 -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_98 x2 x3 x1 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> x1
  Curry_Prelude.C_False -> d_C__case_97 x2 x3 x1 (Curry_Prelude.d_OP_amp_amp x3
    (d_C_isRed (d_C_left x2 cd cs) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_98 x2 x3 x1 l cd
    cs) (d_C__case_98 x2 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_98 x2
    x3 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_98 x2 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_98" [show x2, show x3, show x1, show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_98" (showCons x4))

d_C__case_97 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> C_Tree t0 -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_97 x2 x3 x1 x12 cd cs = case x12 of
  Curry_Prelude.C_True -> let x4 = d_OP_reviseLeft_dot_uscore_hash_selFP38_hash_col
                                x1 cd cs
                              x5 = d_OP_reviseLeft_dot_uscore_hash_selFP39_hash_x
                                x1 cd cs
                              x6 = d_OP_reviseLeft_dot_uscore_hash_selFP40_hash_a
                                x1 cd cs
                              x7 = d_OP_reviseLeft_dot_uscore_hash_selFP41_hash_z
                                x1 cd cs
                              x8 = d_OP_reviseLeft_dot_uscore_hash_selFP42_hash_y
                                x1 cd cs
                              x9 = d_OP_reviseLeft_dot_uscore_hash_selFP43_hash_b
                                x1 cd cs
                              x10 = d_OP_reviseLeft_dot_uscore_hash_selFP44_hash_c
                                x1 cd cs
                              x11 = d_OP_reviseLeft_dot_uscore_hash_selFP45_hash_d
                                x1 cd cs
    in C_Tree x4 x8 (C_Tree C_Black x5 (d_C_singleBlack x6 cd cs) x9) (C_Tree
    C_Black x7 x10 x11)
  Curry_Prelude.C_False -> d_C__case_96 x2 x3 x1 (Curry_Prelude.d_OP_amp_amp x3
    (d_C_isRed (d_C_right x2 cd cs) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_97 x2 x3 x1 l cd
    cs) (d_C__case_97 x2 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_97 x2
    x3 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_97 x2 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_97" [show x2, show x3, show x1, show x12] info)
  _ -> failCons cd (consFail "RedBlackTree._case_97" (showCons x12))

d_C__case_96 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> C_Tree t0 -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_96 x2 x3 x1 x20 cd cs = case x20 of
  Curry_Prelude.C_True -> let x12 = d_OP_reviseLeft_dot_uscore_hash_selFP47_hash_col
                                x1 cd cs
                              x13 = d_OP_reviseLeft_dot_uscore_hash_selFP48_hash_x
                                x1 cd cs
                              x14 = d_OP_reviseLeft_dot_uscore_hash_selFP49_hash_a
                                x1 cd cs
                              x15 = d_OP_reviseLeft_dot_uscore_hash_selFP50_hash_y
                                x1 cd cs
                              x16 = d_OP_reviseLeft_dot_uscore_hash_selFP51_hash_b
                                x1 cd cs
                              x17 = d_OP_reviseLeft_dot_uscore_hash_selFP52_hash_z
                                x1 cd cs
                              x18 = d_OP_reviseLeft_dot_uscore_hash_selFP53_hash_c
                                x1 cd cs
                              x19 = d_OP_reviseLeft_dot_uscore_hash_selFP54_hash_d
                                x1 cd cs
    in C_Tree x12 x15 (C_Tree C_Black x13 (d_C_singleBlack x14 cd cs) x16)
    (C_Tree C_Black x17 x18 x19)
  Curry_Prelude.C_False -> d_C__case_95 x1 x3 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_96 x2 x3 x1 l cd
    cs) (d_C__case_96 x2 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_96 x2
    x3 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_96 x2 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_96" [show x2, show x3, show x1, show x20] info)
  _ -> failCons cd (consFail "RedBlackTree._case_96" (showCons x20))

d_C__case_95 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_95 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> let x20 = d_OP_reviseLeft_dot_uscore_hash_selFP56_hash_col
                                x1 cd cs
                              x21 = d_OP_reviseLeft_dot_uscore_hash_selFP57_hash_x
                                x1 cd cs
                              x22 = d_OP_reviseLeft_dot_uscore_hash_selFP58_hash_a
                                x1 cd cs
                              x23 = d_OP_reviseLeft_dot_uscore_hash_selFP59_hash_y
                                x1 cd cs
                              x24 = d_OP_reviseLeft_dot_uscore_hash_selFP60_hash_b
                                x1 cd cs
                              x25 = d_OP_reviseLeft_dot_uscore_hash_selFP61_hash_c
                                x1 cd cs
    in C_Tree (d_C__case_94 x20 (Curry_Prelude.d_OP_eq_eq x20 C_Red cd cs) cd
    cs) x21 (d_C_singleBlack x22 cd cs) (C_Tree C_Red x23 x24 x25)
  Curry_Prelude.C_False -> d_C__case_93 x1 (Curry_Prelude.d_C_otherwise cd cs)
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_95 x1 l cd cs)
    (d_C__case_95 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_95 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_95 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_95" [show x1, show x3] info)
  _ -> failCons cd (consFail "RedBlackTree._case_95" (showCons x3))

d_C__case_93 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_93 x1 x31 cd cs = case x31 of
  Curry_Prelude.C_True -> let x26 = d_OP_reviseLeft_dot_uscore_hash_selFP63_hash_x
                                x1 cd cs
                              x27 = d_OP_reviseLeft_dot_uscore_hash_selFP64_hash_a
                                x1 cd cs
                              x28 = d_OP_reviseLeft_dot_uscore_hash_selFP65_hash_y
                                x1 cd cs
                              x29 = d_OP_reviseLeft_dot_uscore_hash_selFP66_hash_b
                                x1 cd cs
                              x30 = d_OP_reviseLeft_dot_uscore_hash_selFP67_hash_c
                                x1 cd cs
    in C_Tree C_Black x28 (d_C_reviseLeft (C_Tree C_Red x26 x27 x29) cd cs) x30
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_93 x1 l cd cs)
    (d_C__case_93 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_93 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_93 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_93" [show x1, show x31] info)
  _ -> failCons cd (consFail "RedBlackTree._case_93" (showCons x31))

d_C__case_94 :: C_Color -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> C_Color
d_C__case_94 x20 x21 cd cs = case x21 of
  Curry_Prelude.C_True -> C_Black
  Curry_Prelude.C_False -> C_DoublyBlack
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_94 x20 l cd cs)
    (d_C__case_94 x20 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_94 x20
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_94 x20 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_94" [show x20, show x21] info)
  _ -> failCons cd (consFail "RedBlackTree._case_94" (showCons x21))

d_C__case_99 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_99 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> d_C_reviseLeft x1 cd cs
  Curry_Prelude.C_False -> x1
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_99 x1 l cd cs)
    (d_C__case_99 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_99 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_99 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_99" [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree._case_99" (showCons x2))

d_C__case_101 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_101 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_100 x9 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_101 l cd cs) (d_C__case_101 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_101 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_101 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_101" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_101" (showCons x5))

d_C__case_100 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_100 x9 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x9
  Choice_C_Tree d i l r -> narrow d i (d_C__case_100 x9 l cd cs) (d_C__case_100
    x9 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_100 x9 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_100 x9 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_100" [show x9
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_100" (showCons x8))

d_C__case_103 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_103 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_102 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_103 l cd cs) (d_C__case_103 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_103 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_103 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_103" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_103" (showCons x5))

d_C__case_102 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_102 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x13
  Choice_C_Tree d i l r -> narrow d i (d_C__case_102 l cd cs) (d_C__case_102 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_102 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_102 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_102" [show x8]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_102" (showCons x8))

d_C__case_105 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_105 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_104 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_105 l cd cs) (d_C__case_105 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_105 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_105 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_105" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_105" (showCons x5))

d_C__case_104 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_104 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x12
  Choice_C_Tree d i l r -> narrow d i (d_C__case_104 l cd cs) (d_C__case_104 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_104 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_104 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_104" [show x8]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_104" (showCons x8))

d_C__case_107 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_107 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_106 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_107 l cd cs) (d_C__case_107 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_107 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_107 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_107" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_107" (showCons x5))

d_C__case_106 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_106 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x11
  Choice_C_Tree d i l r -> narrow d i (d_C__case_106 l cd cs) (d_C__case_106 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_106 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_106 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_106" [show x8]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_106" (showCons x8))

d_C__case_109 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_109 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_108 x7 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_109 l cd cs) (d_C__case_109 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_109 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_109 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_109" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_109" (showCons x5))

d_C__case_108 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0
  -> Cover -> ConstStore -> t0
d_C__case_108 x7 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x7
  Choice_C_Tree d i l r -> narrow d i (d_C__case_108 x7 l cd cs) (d_C__case_108
    x7 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_108 x7 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_108 x7 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_108" [show x7
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_108" (showCons x8))

d_C__case_111 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_111 x4 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_110 x4 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_111 x4 l cd cs) (d_C__case_111
    x4 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_111 x4 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_111 x4 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_111" [show x4
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_111" (showCons x5))

d_C__case_110 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_110 x4 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x4
  Choice_C_Tree d i l r -> narrow d i (d_C__case_110 x4 l cd cs) (d_C__case_110
    x4 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_110 x4 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_110 x4 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_110" [show x4
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_110" (showCons x8))

d_C__case_113 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0
  -> Cover -> ConstStore -> t0
d_C__case_113 x3 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_112 x3 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_113 x3 l cd cs) (d_C__case_113
    x3 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_113 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_113 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_113" [show x3
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_113" (showCons x5))

d_C__case_112 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0
  -> Cover -> ConstStore -> t0
d_C__case_112 x3 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x3
  Choice_C_Tree d i l r -> narrow d i (d_C__case_112 x3 l cd cs) (d_C__case_112
    x3 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_112 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_112 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_112" [show x3
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_112" (showCons x8))

d_C__case_115 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_115 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_114 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_115 l cd cs) (d_C__case_115 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_115 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_115 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_115" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_115" (showCons x5))

d_C__case_114 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_114 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x13
  Choice_C_Tree d i l r -> narrow d i (d_C__case_114 l cd cs) (d_C__case_114 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_114 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_114 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_114" [show x9]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_114" (showCons x9))

d_C__case_117 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_117 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_116 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_117 l cd cs) (d_C__case_117 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_117 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_117 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_117" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_117" (showCons x5))

d_C__case_116 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_116 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x12
  Choice_C_Tree d i l r -> narrow d i (d_C__case_116 l cd cs) (d_C__case_116 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_116 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_116 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_116" [show x9]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_116" (showCons x9))

d_C__case_119 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_119 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_118 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_119 l cd cs) (d_C__case_119 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_119 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_119 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_119" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_119" (showCons x5))

d_C__case_118 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_118 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x11
  Choice_C_Tree d i l r -> narrow d i (d_C__case_118 l cd cs) (d_C__case_118 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_118 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_118 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_118" [show x9]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_118" (showCons x9))

d_C__case_121 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_121 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_120 x8 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_121 l cd cs) (d_C__case_121 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_121 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_121 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_121" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_121" (showCons x5))

d_C__case_120 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_120 x8 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x8
  Choice_C_Tree d i l r -> narrow d i (d_C__case_120 x8 l cd cs) (d_C__case_120
    x8 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_120 x8 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_120 x8 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_120" [show x8
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_120" (showCons x9))

d_C__case_123 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_123 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_122 x7 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_123 l cd cs) (d_C__case_123 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_123 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_123 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_123" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_123" (showCons x5))

d_C__case_122 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0
  -> Cover -> ConstStore -> t0
d_C__case_122 x7 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x7
  Choice_C_Tree d i l r -> narrow d i (d_C__case_122 x7 l cd cs) (d_C__case_122
    x7 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_122 x7 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_122 x7 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_122" [show x7
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_122" (showCons x9))

d_C__case_125 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_125 x4 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_124 x4 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_125 x4 l cd cs) (d_C__case_125
    x4 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_125 x4 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_125 x4 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_125" [show x4
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_125" (showCons x5))

d_C__case_124 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_124 x4 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x4
  Choice_C_Tree d i l r -> narrow d i (d_C__case_124 x4 l cd cs) (d_C__case_124
    x4 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_124 x4 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_124 x4 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_124" [show x4
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_124" (showCons x9))

d_C__case_127 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0
  -> Cover -> ConstStore -> t0
d_C__case_127 x3 x5 cd cs = case x5 of
  C_Tree x6 x7 x8 x9 -> d_C__case_126 x3 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_127 x3 l cd cs) (d_C__case_127
    x3 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_127 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_127 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_127" [show x3
    , show x5] info)
  _ -> failCons cd (consFail "RedBlackTree._case_127" (showCons x5))

d_C__case_126 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0
  -> Cover -> ConstStore -> t0
d_C__case_126 x3 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x3
  Choice_C_Tree d i l r -> narrow d i (d_C__case_126 x3 l cd cs) (d_C__case_126
    x3 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_126 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_126 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_126" [show x3
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_126" (showCons x9))

d_C__case_130 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_130 x2 x1 x10 cd cs = case x10 of
  Curry_Prelude.C_True -> let x3 = d_OP_balanceR_dot_uscore_hash_selFP22_hash_x
                                x1 cd cs
                              x4 = d_OP_balanceR_dot_uscore_hash_selFP23_hash_a
                                x1 cd cs
                              x5 = d_OP_balanceR_dot_uscore_hash_selFP24_hash_y
                                x1 cd cs
                              x6 = d_OP_balanceR_dot_uscore_hash_selFP25_hash_b
                                x1 cd cs
                              x7 = d_OP_balanceR_dot_uscore_hash_selFP26_hash_z
                                x1 cd cs
                              x8 = d_OP_balanceR_dot_uscore_hash_selFP27_hash_c
                                x1 cd cs
                              x9 = d_OP_balanceR_dot_uscore_hash_selFP28_hash_d
                                x1 cd cs
    in C_Tree C_Red x5 (C_Tree C_Black x3 x4 x6) (C_Tree C_Black x7 x8 x9)
  Curry_Prelude.C_False -> d_C__case_129 x2 x1 (Curry_Prelude.d_OP_amp_amp
    (d_C_isRed x2 cd cs) (d_C_isRed (d_C_left x2 cd cs) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_130 x2 x1 l cd
    cs) (d_C__case_130 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_130 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_130 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_130" [show x2, show x1, show x10] info)
  _ -> failCons cd (consFail "RedBlackTree._case_130" (showCons x10))

d_C__case_129 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_129 x2 x1 x17 cd cs = case x17 of
  Curry_Prelude.C_True -> let x10 = d_OP_balanceR_dot_uscore_hash_selFP30_hash_x
                                x1 cd cs
                              x11 = d_OP_balanceR_dot_uscore_hash_selFP31_hash_a
                                x1 cd cs
                              x12 = d_OP_balanceR_dot_uscore_hash_selFP32_hash_z
                                x1 cd cs
                              x13 = d_OP_balanceR_dot_uscore_hash_selFP33_hash_y
                                x1 cd cs
                              x14 = d_OP_balanceR_dot_uscore_hash_selFP34_hash_b
                                x1 cd cs
                              x15 = d_OP_balanceR_dot_uscore_hash_selFP35_hash_c
                                x1 cd cs
                              x16 = d_OP_balanceR_dot_uscore_hash_selFP36_hash_d
                                x1 cd cs
    in C_Tree C_Red x13 (C_Tree C_Black x10 x11 x14) (C_Tree C_Black x12 x15
    x16)
  Curry_Prelude.C_False -> d_C__case_128 x1 (Curry_Prelude.d_C_otherwise cd cs)
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_129 x2 x1 l cd
    cs) (d_C__case_129 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_129 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_129 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_129" [show x2, show x1, show x17] info)
  _ -> failCons cd (consFail "RedBlackTree._case_129" (showCons x17))

d_C__case_128 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_128 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> x1
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_128 x1 l cd cs)
    (d_C__case_128 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_128 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_128 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_128" [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree._case_128" (showCons x2))

d_C__case_132 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_132 x5 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_131 x5 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_132 x5 l cd cs) (d_C__case_132
    x5 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_132 x5 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_132 x5 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_132" [show x5
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_132" (showCons x4))

d_C__case_131 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_131 x5 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x5
  Choice_C_Tree d i l r -> narrow d i (d_C__case_131 x5 l cd cs) (d_C__case_131
    x5 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_131 x5 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_131 x5 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_131" [show x5
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_131" (showCons x9))

d_C__case_134 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_134 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_133 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_134 l cd cs) (d_C__case_134 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_134 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_134 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_134" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_134" (showCons x4))

d_C__case_133 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_133 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x13
  Choice_C_Tree d i l r -> narrow d i (d_C__case_133 l cd cs) (d_C__case_133 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_133 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_133 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_133" [show x9]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_133" (showCons x9))

d_C__case_136 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_136 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_135 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_136 l cd cs) (d_C__case_136 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_136 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_136 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_136" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_136" (showCons x4))

d_C__case_135 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_135 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x12
  Choice_C_Tree d i l r -> narrow d i (d_C__case_135 l cd cs) (d_C__case_135 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_135 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_135 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_135" [show x9]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_135" (showCons x9))

d_C__case_138 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_138 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_137 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_138 l cd cs) (d_C__case_138 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_138 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_138 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_138" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_138" (showCons x4))

d_C__case_137 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_137 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x11
  Choice_C_Tree d i l r -> narrow d i (d_C__case_137 l cd cs) (d_C__case_137 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_137 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_137 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_137" [show x9]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_137" (showCons x9))

d_C__case_140 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_140 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_139 x8 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_140 l cd cs) (d_C__case_140 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_140 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_140 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_140" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_140" (showCons x4))

d_C__case_139 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_139 x8 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x8
  Choice_C_Tree d i l r -> narrow d i (d_C__case_139 x8 l cd cs) (d_C__case_139
    x8 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_139 x8 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_139 x8 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_139" [show x8
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_139" (showCons x9))

d_C__case_142 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_142 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_141 x7 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_142 l cd cs) (d_C__case_142 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_142 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_142 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_142" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_142" (showCons x4))

d_C__case_141 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0
  -> Cover -> ConstStore -> t0
d_C__case_141 x7 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x7
  Choice_C_Tree d i l r -> narrow d i (d_C__case_141 x7 l cd cs) (d_C__case_141
    x7 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_141 x7 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_141 x7 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_141" [show x7
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_141" (showCons x9))

d_C__case_144 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0
  -> Cover -> ConstStore -> t0
d_C__case_144 x3 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_143 x3 x9 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_144 x3 l cd cs) (d_C__case_144
    x3 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_144 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_144 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_144" [show x3
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_144" (showCons x4))

d_C__case_143 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0
  -> Cover -> ConstStore -> t0
d_C__case_143 x3 x9 cd cs = case x9 of
  C_Tree x10 x11 x12 x13 -> x3
  Choice_C_Tree d i l r -> narrow d i (d_C__case_143 x3 l cd cs) (d_C__case_143
    x3 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_143 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_143 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_143" [show x3
    , show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_143" (showCons x9))

d_C__case_146 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_146 x5 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_145 x5 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_146 x5 l cd cs) (d_C__case_146
    x5 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_146 x5 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_146 x5 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_146" [show x5
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_146" (showCons x4))

d_C__case_145 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_145 x5 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x5
  Choice_C_Tree d i l r -> narrow d i (d_C__case_145 x5 l cd cs) (d_C__case_145
    x5 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_145 x5 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_145 x5 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_145" [show x5
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_145" (showCons x8))

d_C__case_148 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_148 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_147 x9 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_148 l cd cs) (d_C__case_148 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_148 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_148 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_148" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_148" (showCons x4))

d_C__case_147 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_147 x9 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x9
  Choice_C_Tree d i l r -> narrow d i (d_C__case_147 x9 l cd cs) (d_C__case_147
    x9 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_147 x9 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_147 x9 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_147" [show x9
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_147" (showCons x8))

d_C__case_150 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_150 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_149 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_150 l cd cs) (d_C__case_150 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_150 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_150 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_150" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_150" (showCons x4))

d_C__case_149 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_149 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x13
  Choice_C_Tree d i l r -> narrow d i (d_C__case_149 l cd cs) (d_C__case_149 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_149 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_149 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_149" [show x8]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_149" (showCons x8))

d_C__case_152 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_152 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_151 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_152 l cd cs) (d_C__case_152 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_152 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_152 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_152" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_152" (showCons x4))

d_C__case_151 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_151 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x12
  Choice_C_Tree d i l r -> narrow d i (d_C__case_151 l cd cs) (d_C__case_151 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_151 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_151 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_151" [show x8]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_151" (showCons x8))

d_C__case_154 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_154 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_153 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_154 l cd cs) (d_C__case_154 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_154 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_154 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_154" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_154" (showCons x4))

d_C__case_153 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_153 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x11
  Choice_C_Tree d i l r -> narrow d i (d_C__case_153 l cd cs) (d_C__case_153 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_153 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_153 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_153" [show x8]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_153" (showCons x8))

d_C__case_156 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> t0
d_C__case_156 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_155 x7 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_156 l cd cs) (d_C__case_156 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_156 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_156 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_156" [show x4]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_156" (showCons x4))

d_C__case_155 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0
  -> Cover -> ConstStore -> t0
d_C__case_155 x7 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x7
  Choice_C_Tree d i l r -> narrow d i (d_C__case_155 x7 l cd cs) (d_C__case_155
    x7 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_155 x7 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_155 x7 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_155" [show x7
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_155" (showCons x8))

d_C__case_158 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0
  -> Cover -> ConstStore -> t0
d_C__case_158 x3 x4 cd cs = case x4 of
  C_Tree x6 x7 x8 x9 -> d_C__case_157 x3 x8 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_158 x3 l cd cs) (d_C__case_158
    x3 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_158 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_158 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_158" [show x3
    , show x4] info)
  _ -> failCons cd (consFail "RedBlackTree._case_158" (showCons x4))

d_C__case_157 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> C_Tree t0
  -> Cover -> ConstStore -> t0
d_C__case_157 x3 x8 cd cs = case x8 of
  C_Tree x10 x11 x12 x13 -> x3
  Choice_C_Tree d i l r -> narrow d i (d_C__case_157 x3 l cd cs) (d_C__case_157
    x3 r cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_157 x3 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_157 x3 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_157" [show x3
    , show x8] info)
  _ -> failCons cd (consFail "RedBlackTree._case_157" (showCons x8))

d_C__case_161 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_161 x2 x1 x10 cd cs = case x10 of
  Curry_Prelude.C_True -> let x3 = d_OP_balanceL_dot_uscore_hash_selFP6_hash_z
                                x1 cd cs
                              x4 = d_OP_balanceL_dot_uscore_hash_selFP7_hash_y
                                x1 cd cs
                              x5 = d_OP_balanceL_dot_uscore_hash_selFP8_hash_x
                                x1 cd cs
                              x6 = d_OP_balanceL_dot_uscore_hash_selFP9_hash_a
                                x1 cd cs
                              x7 = d_OP_balanceL_dot_uscore_hash_selFP10_hash_b
                                x1 cd cs
                              x8 = d_OP_balanceL_dot_uscore_hash_selFP11_hash_c
                                x1 cd cs
                              x9 = d_OP_balanceL_dot_uscore_hash_selFP12_hash_d
                                x1 cd cs
    in C_Tree C_Red x4 (C_Tree C_Black x5 x6 x7) (C_Tree C_Black x3 x8 x9)
  Curry_Prelude.C_False -> d_C__case_160 x2 x1 (Curry_Prelude.d_OP_amp_amp
    (d_C_isRed x2 cd cs) (d_C_isRed (d_C_right x2 cd cs) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_161 x2 x1 l cd
    cs) (d_C__case_161 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_161 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_161 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_161" [show x2, show x1, show x10] info)
  _ -> failCons cd (consFail "RedBlackTree._case_161" (showCons x10))

d_C__case_160 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_160 x2 x1 x17 cd cs = case x17 of
  Curry_Prelude.C_True -> let x10 = d_OP_balanceL_dot_uscore_hash_selFP14_hash_z
                                x1 cd cs
                              x11 = d_OP_balanceL_dot_uscore_hash_selFP15_hash_x
                                x1 cd cs
                              x12 = d_OP_balanceL_dot_uscore_hash_selFP16_hash_a
                                x1 cd cs
                              x13 = d_OP_balanceL_dot_uscore_hash_selFP17_hash_y
                                x1 cd cs
                              x14 = d_OP_balanceL_dot_uscore_hash_selFP18_hash_b
                                x1 cd cs
                              x15 = d_OP_balanceL_dot_uscore_hash_selFP19_hash_c
                                x1 cd cs
                              x16 = d_OP_balanceL_dot_uscore_hash_selFP20_hash_d
                                x1 cd cs
    in C_Tree C_Red x13 (C_Tree C_Black x11 x12 x14) (C_Tree C_Black x10 x15
    x16)
  Curry_Prelude.C_False -> d_C__case_159 x1 (Curry_Prelude.d_C_otherwise cd cs)
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_160 x2 x1 l cd
    cs) (d_C__case_160 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_160 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_160 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_160" [show x2, show x1, show x17] info)
  _ -> failCons cd (consFail "RedBlackTree._case_160" (showCons x17))

d_C__case_159 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_159 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> x1
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_159 x1 l cd cs)
    (d_C__case_159 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_159 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_159 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_159" [show x1, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree._case_159" (showCons x2))

d_C__case_162 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> t0 -> C_Color -> Cover -> ConstStore -> C_Tree t0
d_C__case_162 x5 x4 x3 x2 cd cs = case x2 of
  C_Red -> C_Tree C_Red x3 x4 x5
  C_Black -> C_Tree C_Black x3 x4 x5
  C_DoublyBlack -> C_Tree C_Black x3 x4 x5
  Choice_C_Color d i l r -> narrow d i (d_C__case_162 x5 x4 x3 l cd cs)
    (d_C__case_162 x5 x4 x3 r cd cs)
  Choices_C_Color d i xs -> narrows cs d i (\z -> d_C__case_162 x5 x4 x3 z cd
    cs) xs
  Guard_C_Color d c e -> guardCons d c (d_C__case_162 x5 x4 x3 e cd $! addCs c
    cs)
  Fail_C_Color d info -> failCons d (traceFail "RedBlackTree._case_162" [show x5
    , show x4, show x3, show x2] info)
  _ -> failCons cd (consFail "RedBlackTree._case_162" (showCons x2))

d_C__case_163 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> t0
d_C__case_163 x5 x3 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> x3
  Curry_Prelude.C_False -> d_OP_deleteTree_dot_rightMost_dot_55 x5 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_163 x5 x3 l cd
    cs) (d_C__case_163 x5 x3 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_163 x5
    x3 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_163 x5 x3 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_163" [show x5, show x3, show x6] info)
  _ -> failCons cd (consFail "RedBlackTree._case_163" (showCons x6))

d_C__case_165 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> C_Tree t0
d_C__case_165 x2 cd cs = case x2 of
  C_Empty -> C_Empty
  C_Tree x3 x4 x5 x6 -> d_C__case_164 x6 x5 x4 x3 cd cs
  Choice_C_Tree d i l r -> narrow d i (d_C__case_165 l cd cs) (d_C__case_165 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_165 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_165 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_165" [show x2]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_165" (showCons x2))

d_C__case_164 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> t0 -> C_Color -> Cover -> ConstStore -> C_Tree t0
d_C__case_164 x6 x5 x4 x3 cd cs = case x3 of
  C_Red -> C_Tree C_Black x4 x5 x6
  C_Black -> C_Tree C_DoublyBlack x4 x5 x6
  C_DoublyBlack -> C_Tree C_DoublyBlack x4 x5 x6
  Choice_C_Color d i l r -> narrow d i (d_C__case_164 x6 x5 x4 l cd cs)
    (d_C__case_164 x6 x5 x4 r cd cs)
  Choices_C_Color d i xs -> narrows cs d i (\z -> d_C__case_164 x6 x5 x4 z cd
    cs) xs
  Guard_C_Color d c e -> guardCons d c (d_C__case_164 x6 x5 x4 e cd $! addCs c
    cs)
  Fail_C_Color d info -> failCons d (traceFail "RedBlackTree._case_164" [show x6
    , show x5, show x4, show x3] info)
  _ -> failCons cd (consFail "RedBlackTree._case_164" (showCons x3))

d_C__case_170 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0 -> (t0
  -> Cover -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> (t0 -> Cover -> ConstStore -> t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool) -> C_Tree t0 -> C_Tree t0 -> C_Color
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_170 x6 x3 x1 x2 x8 x7 x5 x9 cd cs = case x9 of
  Curry_Prelude.C_True -> d_C__case_169 x7 x8 x2 x1 x5 (d_C_isEmptyTree x7 cd
    cs) cd cs
  Curry_Prelude.C_False -> d_C__case_167 x6 x3 x2 x8 x1 x7 x5
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply x2 x3 cd cs) x6 cd cs) cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_170 x6 x3 x1 x2
    x8 x7 x5 l cd cs) (d_C__case_170 x6 x3 x1 x2 x8 x7 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_170 x6
    x3 x1 x2 x8 x7 x5 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_170 x6 x3 x1 x2
    x8 x7 x5 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_170" [show x6, show x3, show x1, show x2, show x8, show
    x7, show x5, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_170" (showCons x9))

nd_C__case_170 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0 -> Func t0
  (Func t0 Curry_Prelude.C_Bool) -> Func t0 (Func t0 Curry_Prelude.C_Bool)
  -> C_Tree t0 -> C_Tree t0 -> C_Color -> Curry_Prelude.C_Bool -> IDSupply
  -> Cover -> ConstStore -> C_Tree t0
nd_C__case_170 x6 x3 x1 x2 x8 x7 x5 x9 s cd cs = case x9 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` nd_C__case_169 x7 x8 x2 x1 x5 (d_C_isEmptyTree x7 cd cs) s0 cd
    cs
  Curry_Prelude.C_False -> let s4 = s
    in s4 `seq` (let s3 = leftSupply s4
                     s2 = rightSupply s4
    in s3 `seq` (s2 `seq` nd_C__case_167 x6 x3 x2 x8 x1 x7 x5
    (let s1 = leftSupply s2
         s0 = rightSupply s2
    in s1 `seq` (s0 `seq` Curry_Prelude.nd_C_apply (Curry_Prelude.nd_C_apply x2
    x3 s0 cd cs) x6 s1 cd cs)) s3 cd cs))
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_170 x6 x3 x1 x2
    x8 x7 x5 l s cd cs) (nd_C__case_170 x6 x3 x1 x2 x8 x7 x5 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_170 x6
    x3 x1 x2 x8 x7 x5 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_170 x6 x3 x1 x2
    x8 x7 x5 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_170" [show x6, show x3, show x1, show x2, show x8, show
    x7, show x5, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_170" (showCons x9))

d_C__case_167 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0 -> (t0
  -> Cover -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> C_Tree t0 -> (t0 -> Cover -> ConstStore -> t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool) -> C_Tree t0 -> C_Color -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_167 x6 x3 x2 x8 x1 x7 x5 x9 cd cs = case x9 of
  Curry_Prelude.C_True -> d_C_delBalanceL (C_Tree x5 x6 (d_C_deleteTree x1 x2 x3
    x7 cd cs) x8) cd cs
  Curry_Prelude.C_False -> d_C__case_166 x8 x3 x2 x1 x7 x6 x5
    (Curry_Prelude.d_C_otherwise cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_167 x6 x3 x2 x8
    x1 x7 x5 l cd cs) (d_C__case_167 x6 x3 x2 x8 x1 x7 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_167 x6
    x3 x2 x8 x1 x7 x5 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_167 x6 x3 x2 x8
    x1 x7 x5 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_167" [show x6, show x3, show x2, show x8, show x1, show
    x7, show x5, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_167" (showCons x9))

nd_C__case_167 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0 -> Func t0
  (Func t0 Curry_Prelude.C_Bool) -> C_Tree t0 -> Func t0 (Func t0
  Curry_Prelude.C_Bool) -> C_Tree t0 -> C_Color -> Curry_Prelude.C_Bool
  -> IDSupply -> Cover -> ConstStore -> C_Tree t0
nd_C__case_167 x6 x3 x2 x8 x1 x7 x5 x9 s cd cs = case x9 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` d_C_delBalanceL (C_Tree x5 x6 (nd_C_deleteTree x1 x2 x3 x7 s0 cd
    cs) x8) cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_166 x8 x3 x2 x1 x7 x6 x5 (Curry_Prelude.d_C_otherwise
    cd cs) s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_167 x6 x3 x2 x8
    x1 x7 x5 l s cd cs) (nd_C__case_167 x6 x3 x2 x8 x1 x7 x5 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_167 x6
    x3 x2 x8 x1 x7 x5 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_167 x6 x3 x2 x8
    x1 x7 x5 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_167" [show x6, show x3, show x2, show x8, show x1, show
    x7, show x5, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_167" (showCons x9))

d_C__case_166 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> t0 -> (t0
  -> Cover -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> (t0 -> Cover -> ConstStore -> t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool) -> C_Tree t0 -> t0 -> C_Color -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_166 x8 x3 x2 x1 x7 x6 x5 x9 cd cs = case x9 of
  Curry_Prelude.C_True -> d_C_delBalanceR (C_Tree x5 x6 x7 (d_C_deleteTree x1 x2
    x3 x8 cd cs)) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_166 x8 x3 x2 x1
    x7 x6 x5 l cd cs) (d_C__case_166 x8 x3 x2 x1 x7 x6 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_166 x8
    x3 x2 x1 x7 x6 x5 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_166 x8 x3 x2 x1
    x7 x6 x5 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_166" [show x8, show x3, show x2, show x1, show x7, show
    x6, show x5, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_166" (showCons x9))

nd_C__case_166 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> t0
  -> Func t0 (Func t0 Curry_Prelude.C_Bool) -> Func t0 (Func t0
  Curry_Prelude.C_Bool) -> C_Tree t0 -> t0 -> C_Color -> Curry_Prelude.C_Bool
  -> IDSupply -> Cover -> ConstStore -> C_Tree t0
nd_C__case_166 x8 x3 x2 x1 x7 x6 x5 x9 s cd cs = case x9 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` d_C_delBalanceR (C_Tree x5 x6 x7 (nd_C_deleteTree x1 x2 x3 x8 s0
    cd cs)) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_166 x8 x3 x2 x1
    x7 x6 x5 l s cd cs) (nd_C__case_166 x8 x3 x2 x1 x7 x6 x5 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_166 x8
    x3 x2 x1 x7 x6 x5 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_166 x8 x3 x2 x1
    x7 x6 x5 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_166" [show x8, show x3, show x2, show x1, show x7, show
    x6, show x5, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_166" (showCons x9))

d_C__case_169 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> (t0 -> Cover -> ConstStore -> t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool) -> (t0 -> Cover -> ConstStore -> t0 -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool) -> C_Color -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_169 x7 x8 x2 x1 x5 x9 cd cs = case x9 of
  Curry_Prelude.C_True -> d_OP_deleteTree_dot_addColor_dot_55 x5 x8 cd cs
  Curry_Prelude.C_False -> d_C__case_168 x8 x7 x2 x1 x5 (d_C_isEmptyTree x8 cd
    cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_169 x7 x8 x2 x1
    x5 l cd cs) (d_C__case_169 x7 x8 x2 x1 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_169 x7
    x8 x2 x1 x5 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_169 x7 x8 x2 x1
    x5 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_169" [show x7, show x8, show x2, show x1, show x5, show
    x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_169" (showCons x9))

nd_C__case_169 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Func t0 (Func t0 Curry_Prelude.C_Bool) -> Func t0 (Func t0
  Curry_Prelude.C_Bool) -> C_Color -> Curry_Prelude.C_Bool -> IDSupply -> Cover
  -> ConstStore -> C_Tree t0
nd_C__case_169 x7 x8 x2 x1 x5 x9 s cd cs = case x9 of
  Curry_Prelude.C_True -> d_OP_deleteTree_dot_addColor_dot_55 x5 x8 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_168 x8 x7 x2 x1 x5 (d_C_isEmptyTree x8 cd cs) s0 cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_169 x7 x8 x2 x1
    x5 l s cd cs) (nd_C__case_169 x7 x8 x2 x1 x5 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_169 x7
    x8 x2 x1 x5 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_169 x7 x8 x2 x1
    x5 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_169" [show x7, show x8, show x2, show x1, show x5, show
    x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_169" (showCons x9))

d_C__case_168 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> (t0 -> Cover -> ConstStore -> t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool) -> (t0 -> Cover -> ConstStore -> t0 -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool) -> C_Color -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_168 x8 x7 x2 x1 x5 x10 cd cs = case x10 of
  Curry_Prelude.C_True -> d_OP_deleteTree_dot_addColor_dot_55 x5 x7 cd cs
  Curry_Prelude.C_False -> let x9 = d_OP_deleteTree_dot_rightMost_dot_55 x7 cd
                                 cs
    in d_C_delBalanceL (C_Tree x5 x9 (d_C_deleteTree x1 x2 x9 x7 cd cs) x8) cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_168 x8 x7 x2 x1
    x5 l cd cs) (d_C__case_168 x8 x7 x2 x1 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_168 x8
    x7 x2 x1 x5 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_168 x8 x7 x2 x1
    x5 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_168" [show x8, show x7, show x2, show x1, show x5, show
    x10] info)
  _ -> failCons cd (consFail "RedBlackTree._case_168" (showCons x10))

nd_C__case_168 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> C_Tree t0
  -> Func t0 (Func t0 Curry_Prelude.C_Bool) -> Func t0 (Func t0
  Curry_Prelude.C_Bool) -> C_Color -> Curry_Prelude.C_Bool -> IDSupply -> Cover
  -> ConstStore -> C_Tree t0
nd_C__case_168 x8 x7 x2 x1 x5 x10 s cd cs = case x10 of
  Curry_Prelude.C_True -> d_OP_deleteTree_dot_addColor_dot_55 x5 x7 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` (let x9 = d_OP_deleteTree_dot_rightMost_dot_55 x7 cd cs
    in d_C_delBalanceL (C_Tree x5 x9 (nd_C_deleteTree x1 x2 x9 x7 s0 cd cs) x8)
    cd cs)
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_168 x8 x7 x2 x1
    x5 l s cd cs) (nd_C__case_168 x8 x7 x2 x1 x5 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_168 x8
    x7 x2 x1 x5 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_168 x8 x7 x2 x1
    x5 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_168" [show x8, show x7, show x2, show x1, show x5, show
    x10] info)
  _ -> failCons cd (consFail "RedBlackTree._case_168" (showCons x10))

d_C__case_173 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0 -> (t0
  -> Cover -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> (t0 -> Cover -> ConstStore -> t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool) -> C_Tree t0 -> C_Tree t0 -> C_Color
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_173 x6 x1 x2 x3 x8 x7 x5 x9 cd cs = case x9 of
  Curry_Prelude.C_True -> C_Tree x5 x1 x7 x8
  Curry_Prelude.C_False -> d_C__case_172 x6 x1 x3 x8 x2 x7 x5
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply x3 x1 cd cs) x6 cd cs) cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_173 x6 x1 x2 x3
    x8 x7 x5 l cd cs) (d_C__case_173 x6 x1 x2 x3 x8 x7 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_173 x6
    x1 x2 x3 x8 x7 x5 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_173 x6 x1 x2 x3
    x8 x7 x5 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_173" [show x6, show x1, show x2, show x3, show x8, show
    x7, show x5, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_173" (showCons x9))

nd_C__case_173 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0 -> Func t0
  (Func t0 Curry_Prelude.C_Bool) -> Func t0 (Func t0 Curry_Prelude.C_Bool)
  -> C_Tree t0 -> C_Tree t0 -> C_Color -> Curry_Prelude.C_Bool -> IDSupply
  -> Cover -> ConstStore -> C_Tree t0
nd_C__case_173 x6 x1 x2 x3 x8 x7 x5 x9 s cd cs = case x9 of
  Curry_Prelude.C_True -> C_Tree x5 x1 x7 x8
  Curry_Prelude.C_False -> let s4 = s
    in s4 `seq` (let s3 = leftSupply s4
                     s2 = rightSupply s4
    in s3 `seq` (s2 `seq` nd_C__case_172 x6 x1 x3 x8 x2 x7 x5
    (let s1 = leftSupply s2
         s0 = rightSupply s2
    in s1 `seq` (s0 `seq` Curry_Prelude.nd_C_apply (Curry_Prelude.nd_C_apply x3
    x1 s0 cd cs) x6 s1 cd cs)) s3 cd cs))
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_173 x6 x1 x2 x3
    x8 x7 x5 l s cd cs) (nd_C__case_173 x6 x1 x2 x3 x8 x7 x5 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_173 x6
    x1 x2 x3 x8 x7 x5 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_173 x6 x1 x2 x3
    x8 x7 x5 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_173" [show x6, show x1, show x2, show x3, show x8, show
    x7, show x5, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_173" (showCons x9))

d_C__case_172 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0 -> (t0
  -> Cover -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> C_Tree t0 -> (t0 -> Cover -> ConstStore -> t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool) -> C_Tree t0 -> C_Color -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> C_Tree t0
d_C__case_172 x6 x1 x3 x8 x2 x7 x5 x9 cd cs = case x9 of
  Curry_Prelude.C_True -> d_C_balanceL (C_Tree x5 x6
    (d_OP_updateTree_dot_upd_dot_34 x1 x2 x3 x7 cd cs) x8) cd cs
  Curry_Prelude.C_False -> d_C__case_171 x8 x3 x2 x1 x7 x6 x5
    (Curry_Prelude.d_C_otherwise cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_172 x6 x1 x3 x8
    x2 x7 x5 l cd cs) (d_C__case_172 x6 x1 x3 x8 x2 x7 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_172 x6
    x1 x3 x8 x2 x7 x5 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_172 x6 x1 x3 x8
    x2 x7 x5 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_172" [show x6, show x1, show x3, show x8, show x2, show
    x7, show x5, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_172" (showCons x9))

nd_C__case_172 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0 -> Func t0
  (Func t0 Curry_Prelude.C_Bool) -> C_Tree t0 -> Func t0 (Func t0
  Curry_Prelude.C_Bool) -> C_Tree t0 -> C_Color -> Curry_Prelude.C_Bool
  -> IDSupply -> Cover -> ConstStore -> C_Tree t0
nd_C__case_172 x6 x1 x3 x8 x2 x7 x5 x9 s cd cs = case x9 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` d_C_balanceL (C_Tree x5 x6 (nd_OP_updateTree_dot_upd_dot_34 x1
    x2 x3 x7 s0 cd cs) x8) cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_171 x8 x3 x2 x1 x7 x6 x5 (Curry_Prelude.d_C_otherwise
    cd cs) s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_172 x6 x1 x3 x8
    x2 x7 x5 l s cd cs) (nd_C__case_172 x6 x1 x3 x8 x2 x7 x5 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_172 x6
    x1 x3 x8 x2 x7 x5 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_172 x6 x1 x3 x8
    x2 x7 x5 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_172" [show x6, show x1, show x3, show x8, show x2, show
    x7, show x5, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_172" (showCons x9))

d_C__case_171 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> (t0
  -> Cover -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> (t0 -> Cover -> ConstStore -> t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool) -> t0 -> C_Tree t0 -> t0 -> C_Color
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> C_Tree t0
d_C__case_171 x8 x3 x2 x1 x7 x6 x5 x9 cd cs = case x9 of
  Curry_Prelude.C_True -> d_C_balanceR (C_Tree x5 x6 x7
    (d_OP_updateTree_dot_upd_dot_34 x1 x2 x3 x8 cd cs)) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_171 x8 x3 x2 x1
    x7 x6 x5 l cd cs) (d_C__case_171 x8 x3 x2 x1 x7 x6 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_171 x8
    x3 x2 x1 x7 x6 x5 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_171 x8 x3 x2 x1
    x7 x6 x5 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_171" [show x8, show x3, show x2, show x1, show x7, show
    x6, show x5, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_171" (showCons x9))

nd_C__case_171 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Func t0
  (Func t0 Curry_Prelude.C_Bool) -> Func t0 (Func t0 Curry_Prelude.C_Bool) -> t0
  -> C_Tree t0 -> t0 -> C_Color -> Curry_Prelude.C_Bool -> IDSupply -> Cover
  -> ConstStore -> C_Tree t0
nd_C__case_171 x8 x3 x2 x1 x7 x6 x5 x9 s cd cs = case x9 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` d_C_balanceR (C_Tree x5 x6 x7 (nd_OP_updateTree_dot_upd_dot_34
    x1 x2 x3 x8 s0 cd cs)) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_171 x8 x3 x2 x1
    x7 x6 x5 l s cd cs) (nd_C__case_171 x8 x3 x2 x1 x7 x6 x5 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_171 x8
    x3 x2 x1 x7 x6 x5 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_171 x8 x3 x2 x1
    x7 x6 x5 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_171" [show x8, show x3, show x2, show x1, show x7, show
    x6, show x5, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_171" (showCons x9))

d_C__case_176 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0 -> (t0
  -> Cover -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> (t0 -> Cover -> ConstStore -> t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool) -> C_Tree t0 -> C_Tree t0 -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.C_Maybe t0
d_C__case_176 x6 x3 x1 x2 x8 x7 x9 cd cs = case x9 of
  Curry_Prelude.C_True -> Curry_Prelude.C_Just x6
  Curry_Prelude.C_False -> d_C__case_175 x6 x3 x2 x8 x1 x7
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply x2 x3 cd cs) x6 cd cs) cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_176 x6 x3 x1 x2
    x8 x7 l cd cs) (d_C__case_176 x6 x3 x1 x2 x8 x7 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_176 x6
    x3 x1 x2 x8 x7 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_176 x6 x3 x1 x2
    x8 x7 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_176" [show x6, show x3, show x1, show x2, show x8, show
    x7, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_176" (showCons x9))

nd_C__case_176 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0 -> Func t0
  (Func t0 Curry_Prelude.C_Bool) -> Func t0 (Func t0 Curry_Prelude.C_Bool)
  -> C_Tree t0 -> C_Tree t0 -> Curry_Prelude.C_Bool -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_Maybe t0
nd_C__case_176 x6 x3 x1 x2 x8 x7 x9 s cd cs = case x9 of
  Curry_Prelude.C_True -> Curry_Prelude.C_Just x6
  Curry_Prelude.C_False -> let s4 = s
    in s4 `seq` (let s3 = leftSupply s4
                     s2 = rightSupply s4
    in s3 `seq` (s2 `seq` nd_C__case_175 x6 x3 x2 x8 x1 x7 (let s1 = leftSupply
                                                                  s2
                                                                s0 = rightSupply
                                                                  s2
    in s1 `seq` (s0 `seq` Curry_Prelude.nd_C_apply (Curry_Prelude.nd_C_apply x2
    x3 s0 cd cs) x6 s1 cd cs)) s3 cd cs))
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_176 x6 x3 x1 x2
    x8 x7 l s cd cs) (nd_C__case_176 x6 x3 x1 x2 x8 x7 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_176 x6
    x3 x1 x2 x8 x7 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_176 x6 x3 x1 x2
    x8 x7 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_176" [show x6, show x3, show x1, show x2, show x8, show
    x7, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_176" (showCons x9))

d_C__case_175 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0 -> (t0
  -> Cover -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> C_Tree t0 -> (t0 -> Cover -> ConstStore -> t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool) -> C_Tree t0 -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_Maybe t0
d_C__case_175 x6 x3 x2 x8 x1 x7 x9 cd cs = case x9 of
  Curry_Prelude.C_True -> d_C_lookupTree x1 x2 x3 x7 cd cs
  Curry_Prelude.C_False -> d_C__case_174 x8 x3 x2 x1
    (Curry_Prelude.d_C_otherwise cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_175 x6 x3 x2 x8
    x1 x7 l cd cs) (d_C__case_175 x6 x3 x2 x8 x1 x7 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_175 x6
    x3 x2 x8 x1 x7 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_175 x6 x3 x2 x8
    x1 x7 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_175" [show x6, show x3, show x2, show x8, show x1, show
    x7, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_175" (showCons x9))

nd_C__case_175 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0 -> Func t0
  (Func t0 Curry_Prelude.C_Bool) -> C_Tree t0 -> Func t0 (Func t0
  Curry_Prelude.C_Bool) -> C_Tree t0 -> Curry_Prelude.C_Bool -> IDSupply
  -> Cover -> ConstStore -> Curry_Prelude.C_Maybe t0
nd_C__case_175 x6 x3 x2 x8 x1 x7 x9 s cd cs = case x9 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` nd_C_lookupTree x1 x2 x3 x7 s0 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_174 x8 x3 x2 x1 (Curry_Prelude.d_C_otherwise cd cs)
    s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_175 x6 x3 x2 x8
    x1 x7 l s cd cs) (nd_C__case_175 x6 x3 x2 x8 x1 x7 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_175 x6
    x3 x2 x8 x1 x7 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_175 x6 x3 x2 x8
    x1 x7 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_175" [show x6, show x3, show x2, show x8, show x1, show
    x7, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_175" (showCons x9))

d_C__case_174 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> t0 -> (t0
  -> Cover -> ConstStore -> t0 -> Cover -> ConstStore -> Curry_Prelude.C_Bool)
  -> (t0 -> Cover -> ConstStore -> t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool) -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_Maybe t0
d_C__case_174 x8 x3 x2 x1 x9 cd cs = case x9 of
  Curry_Prelude.C_True -> d_C_lookupTree x1 x2 x3 x8 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_174 x8 x3 x2 x1 l
    cd cs) (d_C__case_174 x8 x3 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_174 x8
    x3 x2 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_174 x8 x3 x2 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_174" [show x8, show x3, show x2, show x1, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_174" (showCons x9))

nd_C__case_174 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> t0
  -> Func t0 (Func t0 Curry_Prelude.C_Bool) -> Func t0 (Func t0
  Curry_Prelude.C_Bool) -> Curry_Prelude.C_Bool -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_Maybe t0
nd_C__case_174 x8 x3 x2 x1 x9 s cd cs = case x9 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` nd_C_lookupTree x1 x2 x3 x8 s0 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_174 x8 x3 x2 x1
    l s cd cs) (nd_C__case_174 x8 x3 x2 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_174 x8
    x3 x2 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_174 x8 x3 x2 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "RedBlackTree._case_174" [show x8, show x3, show x2, show x1, show x9] info)
  _ -> failCons cd (consFail "RedBlackTree._case_174" (showCons x9))

d_C__case_177 :: forall t0 . (Curry_Prelude.Curry t0) => C_Tree t0 -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C__case_177 x5 cd cs = case x5 of
  C_Empty -> Curry_Prelude.C_True
  C_Tree x6 x7 x8 x9 -> Curry_Prelude.C_False
  Choice_C_Tree d i l r -> narrow d i (d_C__case_177 l cd cs) (d_C__case_177 r
    cd cs)
  Choices_C_Tree d i xs -> narrows cs d i (\z -> d_C__case_177 z cd cs) xs
  Guard_C_Tree d c e -> guardCons d c (d_C__case_177 e cd $! addCs c cs)
  Fail_C_Tree d info -> failCons d (traceFail "RedBlackTree._case_177" [show x5]
    info)
  _ -> failCons cd (consFail "RedBlackTree._case_177" (showCons x5))

